/**
 ******************************************************************************
 *
 * @file        MG82F6P32_OPA0_DRV.h
 *
 * @brief       This is the C code format driver head file.
 *
 * @par         Project
 *              MG82F6P32
 * @version     v1.00
 * @date        2024/03/26
 * @copyright   Copyright (c) 2019 Megawin Technology Co., Ltd.
 *              All rights reserved.
 *
 ******************************************************************************
 * @par         Disclaimer
 *      The Demo software is provided "AS IS" without any warranty, either
 *      expressed or implied, including, but not limited to, the implied warranties
 *      of merchantability and fitness for a particular purpose. The author will
 *      not be liable for any special, incidental, consequential or indirect
 *      damages due to loss of data or any other reason.
 *      These statements agree with the world wide and local dictated laws about
 *      authorship and violence against these laws.
 ******************************************************************************
 ******************************************************************************
 */
#ifndef _MG82F6P32_OPA0_DRV_H
#define _MG82F6P32_OPA0_DRV_H
/**
 *******************************************************************************
 * @brief     Clear OPA0 interrupt flag
 * @details   Set OP0CMPF
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_OPA0_ClearFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_OPA0_ClearFlag()\
    MWT(\
        OPSTA = OPSTA | OP0CMPF;\
    )

/**
 *******************************************************************************
 * @brief       MW_ENABLE/MW_DISABLE OPA0 block
 * @details     Set OP0EN
 * @param[in]   __STATE__  :
 *  @arg\b      MW_ENABLE   :Set to turn on the OPA0 block. At least 5us stable time after OPA0 is enabled.
 *  @arg\b      MW_DISABLE  :Clear to turn off the OPA0 block.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_OPA0_OP0EN_Block(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_OPA0_OP0EN_Block(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(OP0CON0_Page);\
        __STATE__==MW_ENABLE?(OP0CON0 = OP0CON0 |OP0EN):(OP0CON0 = OP0CON0 & ~(OP0EN));\
        __DRV_SFR_PageIndex(0);\
    )

/**
 *******************************************************************************
 * @brief     MW_ENABLE/MW_DISABLE OPA0CMPF ignore interrupt.
 * @details   Set OP0IG
 * @param[in] __STATE__  : configure Ignore OPA0CMPF flag 
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 *  @arg\b    MW_ENABLE  :OPA0CMPF ignore interrupt.
 *  @arg\b    MW_DISABLE :OPA0CMPF normal interrupt.(Default)
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_OPA0_IgnoreOPA0CMPF_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define   __DRV_OPA0_IgnoreOPA0CMPF_Cmd(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(OP0CON0_Page);\
        __STATE__==MW_ENABLE?(OP0CON0 = (OP0CON0 |OP0IG)):(OP0CON0 = OP0CON0 & (~IGADCI));\
        __DRV_SFR_PageIndex(0);\
    )
/**
 *******************************************************************************
 * @brief     Select OPA0 positive input path
 * @details   Set OP0PIS1 OP0PIS0
 * @param[in] __SELECT__  :   config positive pin 
 *  @arg\b    OPA_OPA0PI0 :   PI select Internal reference voltage Bandgap 1.2V .(default)
 *  @arg\b    OPA_OPA0PI1 :   PI select OP0PI (P1.7)
 *  @arg\b    OPA_OPA0PI2 :   PI select PGADO.
 * @return    none
 * @note
 * @par       Example
 * @code
 *    __DRV_OPA0_PositivePinMux_Select(OPA_OPA0PI0);
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_OPA0_PositivePinMux_Select
#define OPA_OPA0PI0 ~(OP0PIS1|OP0PIS0)      /*!< PI select Internal reference voltage Bandgap 1.2V */
#define OPA_OPA0PI1 OP0PIS0                 /*!< PI select OP0PI (P1.7)  */
#define OPA_OPA0PI2 OP0PIS1                 /*!< PI select PGADO  */
/// @endcond
#define __DRV_OPA0_PositivePinMux_Select(__SELECT__)\
    MWT(\
        __DRV_SFR_PageIndex(OP0CON0_Page);\
        OP0CON0 = OP0CON0 & ~(OP0PIS1|OP0PIS0);\
        OP0CON0 =(OP0CON0|(__SELECT__&(OP0PIS1|OP0PIS0)));\
        __DRV_SFR_PageIndex(0);\
    )
/**
 *******************************************************************************
 * @brief      Select OPA0 negative input path
 * @details    Set OP0NIS1 OP0NIS0
 * @param[in]  __SELECT__  : config negative pin 
 *  @arg\b     OPA_OPA0NI0 : NI select Internal reference voltage Bandgap 1.2V .(default)
 *  @arg\b     OPA_OPA0NI1 : NI select OP0NI (P2.2).
 *  @arg\b     OPA_OPA0NI2 : NI select NI select OP0O, Operate as Uni-gain buffer.
 * @return     none
 * @note
 * @par        Example
 * @code
 *    __DRV_OPA0_NegativePinMux_Select(OPA_OPA0NI0);
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_OPA0_NegativePinMux_Select
#define OPA_OPA0NI0 ~(OP0NIS1|OP0NIS0)        /*!< NI select Internal reference voltage Bandgap 1.2V */
#define OPA_OPA0NI1 OP0NIS0                   /*!< NI select OP0NI (P2.2)  */
#define OPA_OPA0NI2 OP0NIS1                   /*!< NI select OP0O, Operate as Uni-gain buffer  */
/// @endcond
#define __DRV_OPA0_NegativePinMux_Select(__SELECT__)\
    MWT(\
        __DRV_SFR_PageIndex(OP0CON0_Page);\
        OP0CON0 = OP0CON0 & ~(OP0NIS1|OP0NIS0);\
        OP0CON0 =(OP0CON0| (__SELECT__&(OP0NIS1|OP0NIS0)));\
        __DRV_SFR_PageIndex(0);\
    )
/**
 *******************************************************************************
 * @brief     MW_ENABLE/MW_DISABLE OPA0 to continue its function during PD mode.
 * @details   Set OP0PDX
 * @param[in] __STATE__  : Configure OPA0 Operation in power down mode.
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 *  @arg\b    MW_ENABLE  : Program the OPA0 to continue its function during PD mode.
 *  @arg\b    MW_DISABLE : Program the OPA0 to be gated off during PD mode.(default)
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_OPA0_OperationInPD(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_OPA0_OperationInPD(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(OPCMP_Page);\
        __STATE__==MW_ENABLE?(OPCMP= (OPCMP|OP0PDX)):(OPCMP=OPCMP&(~OP0PDX));\
        __DRV_SFR_PageIndex(0);\
    )
/**
 *******************************************************************************
 * @brief      Set OPA0 interrupt trigger type
 * @details    Set OP0M1 OP0M0
 * @param[in]  __SELECT__            : Set OPA0 interrupt trigger.
 *  @arg\b     OPA0_NO_TRIGGER       : OPA0 does not trigger interrupt.(default)
 *  @arg\b     OPA0_FALLING_TRIGGER  : OPA0 trigger interrupt on the negative edge.
 *  @arg\b     OPA0_RISING_TRIGGER   : OPA0 trigger interrupt on the positive edge.
 *  @arg\b     OPA0_DUAL_TRIGGER     : OPA0 trigger interrupt on positive and negative edges.
 * @return     None
 * @note
 * @par        Example
 * @code
 *    __DRV_OPA0_TriggerType_Select(OPA0_FALLING_TRIGGER);
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_OPA0_TriggerType_Select
#define OPA0_NO_TRIGGER       ~(OP0M1|OP0M0)
#define OPA0_FALLING_TRIGGER  OP0M0
#define OPA0_RISING_TRIGGER   OP0M1
#define OPA0_DUAL_TRIGGER     (OP0M1|OP0M0)
/// @endcond

#define __DRV_OPA0_TriggerType_Select(__SELECT__)\
    MWT(\
        __DRV_SFR_PageIndex(OPCMP_Page);\
        OPCMP = OPCMP &~(OP0M1|OP0M0);\
        OPCMP = (OPCMP| (__SELECT__&(OP0M1|OP0M0)));\
        __DRV_SFR_PageIndex(0);\
    )
/**
 *******************************************************************************
 * @brief       Get OPA0 interrupt flag
 * @details     The bit is set when the comparator output meets the conditions specified for the trigger and OP0EN is set.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_OPA0_GetFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_OPA0_GetFlag()\
    MWT(\
        OPSTA & OP0CMPF;\
    )
///@cond
bool DRV_OPA0_GetFlag(void);
///@endcond   
#endif

