/**
 ******************************************************************************
 *
 * @file        MG82F6P32_PCA1_DRV.h
 *
 * @brief       This is the C code format driver head file.
 *
 * @par         Project
 *              MG82F6P32
 * @version     v1.00
 * @date        2024/03/14
 * @copyright   Copyright (c) 2019 MegaWin Technology Co., Ltd.
 *              All rights reserved.
 *
 ******************************************************************************
 * @par         Disclaimer
 *      The Demo software is provided "AS IS" without any warranty, either
 *      expressed or implied, including, but not limited to, the implied warranties
 *      of merchantability and fitness for a particular purpose. The author will
 *      not be liable for any special, incidental, consequential or indirect
 *      damages due to loss of data or any other reason.
 *      These statements agree with the world wide and local dictated laws about
 *      authorship and violence against these laws.
 ******************************************************************************
 ******************************************************************************
 */

#ifndef _MG82F6P32_PCA1_DRV_H
#define _MG82F6P32_PCA1_DRV_H





/**
 *******************************************************************************
 * @brief       Enable the PCA1.
 * @details     PCA1 start count
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_Enable();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_Enable()\
      MWT(\
        __DRV_SFR_PageIndex(C1CON_Page);\
        C1R = 1;\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Disable the PCA1.
 * @details     PCA1 stop count
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_Disable();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_Disable()\
      MWT(\
        __DRV_SFR_PageIndex(C1CON_Page);\
        C1R = 0;\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure PCA1 Clock source.
 * @details
 * @param[in]   __CLOCKSRC__ : specifies PCA1 clock selection
 *  @arg\b      PCA1_CK_SYSCLK_DIV_12 : PCA1 clock source by system clock with divider 12.
 *  @arg\b      PCA1_CK_SYSCLK_DIV_2 : PCA1 clock source by system clock with divider 2.
 *  @arg\b      PCA1_CK_T0OF : PCA1 clock source by Timer0 overflow.
 *  @arg\b      PCA1_CK_EC1I : PCA1 clock source by EC1I pin.
 *  @arg\b      PCA1_CK_CKMX16 : PCA1 clock source by CKMIX16.
 *  @arg\b      PCA1_CK_SYSCLK_DIV_1 : PCA1 clock source by system clock.
 *  @arg\b      PCA1_CK_S0TOF : PCA1 clock source by S0BRG overflow.
 *  @arg\b      PCA1_CK_MCKDO : PCA1 clock source by MCK divider output.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_ClockSource_Select(PCA1_CK_SYSCLK_DIV_1);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PCA1_clock_source_definition
#define PCA1_CK_SYSCLK_DIV_12        (0x00)
#define PCA1_CK_SYSCLK_DIV_2         (C1PS0)
#define PCA1_CK_T0OF                 (C1PS1)
#define PCA1_CK_EC1I                 (C1PS1 | C1PS0)
#define PCA1_CK_CKMX16               (C1PS2)
#define PCA1_CK_SYSCLK_DIV_1         (C1PS2 | C1PS0)
#define PCA1_CK_S0TOF                (C1PS2 | C1PS1)
#define PCA1_CK_MCKDO                (C1PS2 | C1PS1 | C1PS0)
/// @endcond

#define __DRV_PCA1_ClockSource_Select(__CLOCKSRC__)\
      MWT(\
        __DRV_SFR_PageIndex(C1MOD_Page);\
        C1MOD = (C1MOD & ~(C1PS2 | C1PS1 | C1PS0)) | __CLOCKSRC__;\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Set PCA1 counter value
 * @details
 * @param[in]   __VALUE__: PCA1 counter value
 *  @arg\b      Value : 0~65535
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_SetCounterValue(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_SetCounterValue(__VALUE__)\
      MWT(\
        __DRV_SFR_PageIndex(CH1_Page);\
        CH1=HIBYTE(__VALUE__);\
        CL1=LOBYTE(__VALUE__);\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Get PCA1 counter value
 * @details     16bit data from PCA1 counter Value
 * @return      Data type word(16bit)
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_GetCounterValue(16bitReg);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_GetCounterValue(__VALUE__)\
      MWT(\
        __DRV_SFR_PageIndex(CH1_Page);\
        __VALUE__ = (CH1 << 8 | CL1);\
        __DRV_SFR_PageIndex(0);\
       )

/**
 *******************************************************************************
 * @brief       Set PCA1 counter reload value
 * @param[in]   __VALUE__: PCA1 counter reload value
 *  @arg\b      Value : 0~65535
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_SetCounterReloadValue(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_SetCounterReloadValue(__VALUE__)\
      MWT(\
        __DRV_SFR_PageIndex(CH1RL_Page);\
        CH1RL=HIBYTE(__VALUE__);\
        CL1RL=LOBYTE(__VALUE__);\
        __DRV_SFR_PageIndex(0);\
       )

/**
 *******************************************************************************
 * @brief       Get PCA1 counter reload value
 * @details     16bit data from PCA1 counter reload Value
 * @return      Data type word(16bit)
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_GetCounterReloadValue(16bitReg);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_GetCounterReloadValue(__VALUE__)\
      MWT(\
        __DRV_SFR_PageIndex(CH1RL_Page);\
        __VALUE__ = (CH1RL << 8 | CL1RL);\
        __DRV_SFR_PageIndex(0);\
       )

/**
 *******************************************************************************
 * @brief       Configure the PCA1 module0 output inverted or non-inverted.
 * @details
 * @param[in]   __STATE__: specifies the PWM0 output Inverted
 *  @arg\b      MW_ENABLE: Inverted Compare/PWM output.
 *  @arg\b      MW_DISABLE: Non-inverted Compare/PWM output. (Default)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_PWM0_SetInverse(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM0_SetInverse(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(C1PWM0_Page);\
        __STATE__==MW_ENABLE?(C1PWM0 = C1PWM0 | (P0INV1)):(C1PWM0 = C1PWM0 & ~(P0INV1));\
        __DRV_SFR_PageIndex(0);\
       )

/**
 *******************************************************************************
 * @brief       Configure the PCA1 module1 output inverted or non-inverted.
 * @details
 * @param[in]   __STATE__: specifies the PWM1 output Inverted
 *  @arg\b      MW_ENABLE: Inverted Compare/PWM output.
 *  @arg\b      MW_DISABLE: Non-inverted Compare/PWM output. (Default)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_PWM1_SetInverse(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM1_SetInverse(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(C1PWM1_Page);\
        __STATE__==MW_ENABLE?(C1PWM1 = C1PWM1 | (P1INV1)):(C1PWM1 = C1PWM1 & ~(P1INV1));\
        __DRV_SFR_PageIndex(0);\
       )

/**
 *******************************************************************************
 * @brief       Initializes the PCA1 base unit for input capture according to the specified
 * @details
 * @param[in]   __CKSRC__ : specifies PCA1 clock selection
 *  @arg\b      PCA1_CK_SYSCLK_DIV_12 : PCA1 clock source by system clock with divider 12
 *  @arg\b      PCA1_CK_SYSCLK_DIV_2 : PCA1 clock source by system clock with divider 2
 *  @arg\b      PCA1_CK_T0OF : PCA1 clock source by timer0 overflow
 *  @arg\b      PCA1_CK_EC1I : PCA1 clock source by EC1I pin
 *  @arg\b      PCA1_CK_CKMX16 : PCA1 clock source by CKMIX16
 *  @arg\b      PCA1_CK_SYSCLK_DIV_1 : PCA1 clock source by system clock
 *  @arg\b      PCA1_CK_S0TOF : PCA1 clock source by S0BRG overflow
 *  @arg\b      PCA1_CK_MCKDO : PCA1 clock source by MCK divider output
 * @param[in]   __PERIOD__ : specifies PCA1 period (0~65536)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_IC_Init(PCA1_CK_SYSCLK_DIV_2, 0x1023);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_IC_Init(__CKSRC__,__PERIOD__)\
      MWT(\
         __DRV_PCA1_Disable();\
         __DRV_SFR_PageIndex(CH1_Page);\
         CH1 = CH1RL = HIBYTE(65536-(__PERIOD__));\
         CL1 = CL1RL = LOBYTE(65536-(__PERIOD__));\
         __DRV_PCA1_ClockSource_Select(__CKSRC__);\
        )

/**
 *******************************************************************************
 * @brief       DeInitializes the PCA1 peripheral
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_DeInit();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_DeInit()\
      MWT(\
        __DRV_PCA1_Disable();\
        __DRV_SFR_PageIndex(C1MOD_Page);\
        C1MOD = 0;\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       PCA1 counter Idle control.
 * @details
 * @param[in]   __STATE__: Specifies PCA1 cannot operate in idle mode
 *  @arg\b      MW_ENABLE: Lets the PCA1 counter be gated off during Idle mode.
 *  @arg\b      MW_DISABLE: Lets the PCA1 counter continue functioning during Idle mode.(Default)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_SetIdleGateOff(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_SetIdleGateOff(__STATE__)\
     MWT(\
        __DRV_SFR_PageIndex(C1MOD_Page);\
        __STATE__==MW_ENABLE?(C1MOD = C1MOD | (C1IDL)):(C1MOD = C1MOD & ~(C1IDL));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Starts the PCA1 Input Capture channel 0 measurement.
 * @details
 * @param[in]   __EDGE__ : specifies PCA1 capture edge selection
 *  @arg\b      PCA1_IC_POSITIVE_EDGE : Capture by a Positive edge trigger
 *  @arg\b      PCA1_IC_NEGATIVE_EDGE : Capture by a Negative edge trigger
 *  @arg\b      PCA1_IC_DUAL_EDGE : Capture by a transition
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_IC0_Start(PCA1_IC_POSITIVE_EDGE);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PCA1_input_capture_edge_definition
#define PCA1_IC_POSITIVE_EDGE        (CAP1P0)
#define PCA1_IC_NEGATIVE_EDGE        (CAP1N0)
#define PCA1_IC_DUAL_EDGE            (CAP1P0 | CAP1N0)
/// @endcond

#define __DRV_PCA1_IC0_Start(__EDGE__)\
      MWT(\
        __DRV_SFR_PageIndex(C1CAPM0_Page);\
        C1CAPM0 = C1CAPM0 & 0x01;\
        C1CAPM0 = C1CAPM0 | (__EDGE__&PCA1_IC_DUAL_EDGE);\
        __DRV_PCA1_Enable();\
        )

/**
 *******************************************************************************
 * @brief       Starts the PCA1 Input Capture channel 1 measurement.
 * @details
 * @param[in]   __EDGE__ : specifies PCA1 capture edge selection
 *  @arg\b      PCA1_IC_POSITIVE_EDGE : Capture by a Positive edge trigger
 *  @arg\b      PCA1_IC_NEGATIVE_EDGE : Capture by a Negative edge trigger
 *  @arg\b      PCA1_IC_DUAL_EDGE : Capture by a transition
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_IC1_Start(PCA1_IC_POSITIVE_EDGE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_IC1_Start(__EDGE__)\
      MWT(\
        __DRV_SFR_PageIndex(C1CAPM1_Page);\
        C1CAPM1 = C1CAPM1 & 0x01;\
        C1CAPM1 = C1CAPM1 | (__EDGE__&PCA1_IC_DUAL_EDGE);\
        __DRV_PCA1_Enable();\
        )

/**
 *******************************************************************************
 * @brief       Stop the PCA1 Input Capture channel 0 measurement.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_IC0_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_IC0_Stop()\
     MWT(\
        __DRV_SFR_PageIndex(C1CAPM0_Page);\
        C1CAPM0 = C1CAPM0 & 0x01;\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Stop the PCA1 Input Capture channel 1 measurement.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_IC1_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_IC1_Stop()\
     MWT(\
        __DRV_SFR_PageIndex(C1CAPM1_Page);\
        C1CAPM1 = C1CAPM1 & 0x01;\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Clear the PCA1 overflow interrupt flag.
 * @details     Clear PCA1 counter overflow flag
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_Overflow_ClearFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_Overflow_ClearFlag()\
      MWT(\
        __DRV_SFR_PageIndex(C1CON_Page);\
        C1F = 0;\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Clear the PCA1 PWM break interrupt flag.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_Break_ClearFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_Break_ClearFlag()\
        AUXR0 = AUXR0 & (~C1BKF);

/**
 *******************************************************************************
 * @brief       Clear the PCA1 modele0 interrupt flag.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_Module0_ClearFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_Module0_ClearFlag()\
      MWT(\
        __DRV_SFR_PageIndex(C1CON_Page);\
        C1CF0 = 0;\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Clear the PCA1 modele1 interrupt flag.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_Module1_ClearFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_Module1_ClearFlag()\
      MWT(\
        __DRV_SFR_PageIndex(C1CON_Page);\
        C1CF1 = 0;\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Get the PCA1 Input Capture channel 0 Value
 * @details     16bit data from PCA1 capture channel 0 Value
 * @return      Data type word(16bit)
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_GetIC0Value(16bitReg);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_GetIC0Value(__VALUE__)\
     MWT(\
        __DRV_SFR_PageIndex(C1CAP0H_Page);\
        __VALUE__ = C1CAP0H << 8 | C1CAP0L;\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Get the PCA1 Input Capture channel 1 Value
 * @details     16bit data from PCA1 capture channel 1 Value
 * @return      Data type word(16bit)
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_GetIC1Value(16bitReg);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_GetIC1Value(__VALUE__)\
     MWT(\
        __DRV_SFR_PageIndex(C1CAP1H_Page);\
        __VALUE__ = C1CAP1H << 8 | C1CAP1L;\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Initializes the PCA1 base unit for output compare according to the specified
 * @details
 * @param[in]   __CKSRC__ : specifies PCA1 clock selection
 *  @arg\b      PCA1_CK_SYSCLK_DIV_12 : PCA1 clock source by system clock with divider 12
 *  @arg\b      PCA1_CK_SYSCLK_DIV_2 : PCA1 clock source by system clock with divider 2
 *  @arg\b      PCA1_CK_T0OF : PCA1 clock source by timer0 overflow
 *  @arg\b      PCA1_CK_EC1I : PCA1 clock source by EC1I pin
 *  @arg\b      PCA1_CK_CKMX16 : PCA1 clock source by CKMIX16
 *  @arg\b      PCA1_CK_SYSCLK_DIV_1 : PCA1 clock source by system clock
 *  @arg\b      PCA1_CK_S0TOF : PCA1 clock source by S0BRG overflow
 *  @arg\b      PCA1_CK_MCKDO : PCA1 clock source by MCK divider output
 * @param[in]   __BUFFERED__ : Buffered mode Configure
 *  @arg\b      PCA1_PWM_UNBUFFER : Unbuffered mode
 *  @arg\b      PCA1_PWM01_BUFFER : PWM channel 0 and channel 1 are buffered mode
 * @param[in]   __PERIOD__ : specifies PCA1 period (0~65536)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_OC_Init(PCA1_CK_SYSCLK_DIV_2,PCA1_PWM01_BUFFER, 1023);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PCA1_PWM_Unbuffered_definition
#define PCA1_PWM_UNBUFFER           (0x00)
#define PCA1_PWM01_BUFFER           (BME01)
/// @endcond

#define __DRV_PCA1_OC_Init(__CKSRC__,__BUFFERED__,__PERIOD__)\
      MWT(\
        __DRV_PCA1_Disable();\
        __DRV_PCA1_ClockSource_Select(__CKSRC__);\
        __DRV_SFR_PageIndex(CH1_Page);\
        CH1 = 0; CH1RL = HIBYTE(65536-(__PERIOD__));\
        CL1 = 0; CL1RL = LOBYTE(65536-(__PERIOD__));\
        (((__BUFFERED__)&PCA1_PWM01_BUFFER)==(0x00)?(C1MOD = C1MOD & ~(BME01)):(C1MOD |= C1MOD | BME01));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief      Starts the PCA1 channel 0 output compare.
 * @details
 * @param[in]  __RES__ : PWMn Resolution Setting
 * @arg\b      PCA1_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b      PCA1_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b      PCA1_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b      PCA1_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]  __VALUE__ : specifies PCA1 Channel 0 compare value(0~65535)
 * @return     None
 * @note
 * @par        Example
 * @code
 *    __DRV_PCA1_OC0_Start(PCA1_PWM_10BIT,256);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PCA1_PWM_Resolution
#define PCA1_PWM_8BIT     (0x00)
#define PCA1_PWM_10BIT    (P0RS0)
#define PCA1_PWM_12BIT    (P0RS1)
#define PCA1_PWM_16BIT    (P0RS1 | P0RS0)
/// @endcond

#define __DRV_PCA1_OC0_Start(__RES__,__VALUE__)\
      MWT(\
        __DRV_SFR_PageIndex(C1PWM0_Page);\
        __RES__==PCA1_PWM_8BIT?(C1CAP0H = LOBYTE(__VALUE__)):(C1CAP0H = HIBYTE(__VALUE__));\
        C1CAP0L = LOBYTE(__VALUE__);\
        C1PWM0 = (C1PWM0 & ~(P0RS11 | P0RS01))|__RES__;\
        C1CAPM0 = (ECOM01 | TOG01 | MAT01);\
        __DRV_PCA1_Enable();\
        )

/**
 *******************************************************************************
 * @brief      Starts the PCA1 channel 1 output compare.
 * @details
 * @param[in]  __RES__ : PWMn Resolution Setting
 * @arg\b      PCA1_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b      PCA1_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b      PCA1_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b      PCA1_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]  __VALUE__ : specifies PCA1 Channel 1 compare value(0~65535)
 * @return     None
 * @note
 * @par        Example
 * @code
 *    __DRV_PCA1_OC1_Start(PCA1_PWM_10BIT,256);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_OC1_Start(__RES__,__VALUE__)\
      MWT(\
        __DRV_SFR_PageIndex(C1PWM1_Page);\
        __RES__==PCA1_PWM_8BIT?(C1CAP1H = LOBYTE(__VALUE__)):(C1CAP1H = HIBYTE(__VALUE__));\
        C1CAP1L = LOBYTE(__VALUE__);\
        C1PWM1 = (C1PWM1 & ~(P1RS11 | P1RS01))|__RES__;\
        C1CAPM1 = (ECOM11 | TOG11 | MAT11);\
        __DRV_PCA1_Enable();\
        )

/**
 *******************************************************************************
 * @brief       Stop the PCA1 output compare channel 0.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_OC0_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_OC0_Stop()\
      MWT(\
        __DRV_SFR_PageIndex(C1PWM0_Page);\
        (C1CAPM0 = C1CAPM0 & 0x01);\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Stop the PCA1 output compare channel 1.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_OC1_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_OC1_Stop()\
      MWT(\
        __DRV_SFR_PageIndex(C1CAPM1_Page);\
        (C1CAPM1 = C1CAPM1 & 0x01);\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Initializes the PCA1 base unit for PWM according to the specified
 * @details
 * @param[in]   __CKSRC__ : specifies PCA1 clock selection
 *  @arg\b      PCA1_CK_SYSCLK_DIV_12 : PCA1 clock source by system clock with divider 12
 *  @arg\b      PCA1_CK_SYSCLK_DIV_2 : PCA1 clock source by system clock with divider 2
 *  @arg\b      PCA1_CK_T0OF : PCA1 clock source by timer0 overflow
 *  @arg\b      PCA1_CK_EC1I : PCA1 clock source by EC1I pin
 *  @arg\b      PCA1_CK_CKMX16 : PCA1 clock source by CKMIX16
 *  @arg\b      PCA1_CK_SYSCLK_DIV_1 : PCA1 clock source by system clock
 *  @arg\b      PCA1_CK_S0TOF : PCA1 clock source by S0BRG overflow
 *  @arg\b      PCA1_CK_MCKDO : PCA1 clock source by MCK divider output
 * @param[in]   __BUFFERED__ : Buffered mode Configure
 *  @arg\b      PCA1_PWM_UNBUFFER : Unbuffered mode
 *  @arg\b      PCA1_PWM01_BUFFER : PWM channel 0 and channel 1 are buffered mode
 * @param[in]   __PERIOD__ : specifies PCA1 period (0~65536)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_PWM_Init(PCA1_CK_SYSCLK_DIV_2,PCA1_PWM01_BUFFER , 1023);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM_Init(__CKSRC__,__BUFFERED__,__PERIOD__)\
      MWT(\
        __DRV_PCA1_Disable();\
        __DRV_PCA1_ClockSource_Select(__CKSRC__);\
        __DRV_SFR_PageIndex(CH1_Page);\
        CH1 = 0; CH1RL = HIBYTE(65536-(__PERIOD__));\
        CL1 = 0; CL1RL = LOBYTE(65536-(__PERIOD__));\
        (((__BUFFERED__)&PCA1_PWM01_BUFFER)==(0x00)?(C1MOD = C1MOD & ~(BME01)):(C1MOD = C1MOD | BME01));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Starts the PCA1 channel 0 PWM output.
 * @details
 * @param[in]   __RES__ : PWMn Resolution Setting
 * @arg\b       PCA1_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b       PCA1_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b       PCA1_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b       PCA1_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]   __DUTY__ : specifies PCA1 Channel 0 duty cycle(0~65535)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_PWM0_Start(PCA1_PWM_16BIT,0x8000)
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM0_Start(__RES__,__DUTY__)\
      MWT(\
        __DRV_SFR_PageIndex(C1PWM0_Page);\
        __RES__==PCA1_PWM_8BIT?(C1CAP0H = LOBYTE(__DUTY__)):(C1CAP0H = HIBYTE(__DUTY__));\
        C1CAP0L = LOBYTE(__DUTY__);\
        C1PWM0 = (C1PWM0 & ~(P0RS11 | P0RS01))|__RES__;\
        C1CAPM0 = (ECOM01  | PWM01);\
        __DRV_PCA1_Enable();\
        )

/**
 *******************************************************************************
 * @brief       Starts the PCA1 channel 1 PWM output.
 * @details
 * @param[in]   __RES__ : PWMn Resolution Setting
 * @arg\b       PCA1_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b       PCA1_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b       PCA1_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b       PCA1_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]   __DUTY__ : specifies PCA1 Channel 1 duty cycle(0~65535)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_PWM1_Start(PCA1_PWM_16BIT,0x8000)
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM1_Start(__RES__,__DUTY__)\
      MWT(\
        __DRV_SFR_PageIndex(C1PWM1_Page);\
        __RES__==PCA1_PWM_8BIT?(C1CAP1H = LOBYTE(__DUTY__)):(C1CAP1H = HIBYTE(__DUTY__));\
        C1CAP1L = LOBYTE(__DUTY__);\
        C1PWM1 = (C1PWM1 & ~(P1RS11 | P1RS01))|__RES__;\
        C1CAPM1 = (ECOM11  | PWM11);\
        __DRV_PCA1_Enable();\
        )

/**
 *******************************************************************************
 * @brief       Stop the PCA1 PWM channel 0.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_PWM0_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM0_Stop()\
     MWT(\
        __DRV_SFR_PageIndex(C1CAPM0_Page);\
        C1CAPM0 = C1CAPM0 & 0x01;\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Stop the PCA1 PWM channel 1.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_PWM1_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM1_Stop()\
     MWT(\
        __DRV_SFR_PageIndex(C1CAPM1_Page);\
        C1CAPM1 = C1CAPM1 & 0x01;\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief     Enable/Disable PCA1 PWM0 output
 * @details
 * @param[in] __STATE__ :  Configure PWM0 output
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PCA1_PWM0_Output_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM0_Output_Cmd(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(C1AOE0_Page);\
        __STATE__==MW_ENABLE?(C1AOE0 = C1AOE0 | C1POE0):(C1AOE0 = C1AOE0 & ~(C1POE0));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief     Enable/Disable PCA1 PWM1 output
 * @details
 * @param[in] __STATE__ :  Configure PWM1 output
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PCA1_PWM1_Output_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM1_Output_Cmd(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(C1AOE0_Page);\
        __STATE__==MW_ENABLE?(C1AOE0 = C1AOE0 | C1POE1):(C1AOE0 = C1AOE0 & ~(C1POE1));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief     Enable/Disable PCA1 PWM central aligned
 * @details
 * @param[in] __STATE__ :  Configure PWM edge aligned or central aligned
 *  @arg\b    MW_ENABLE : PCA1 PWM central aligned mode
 *  @arg\b    MW_DISABLE : PCA1 PWM edge aligned mode (Default)
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PCA1_PWM_CentralAligned_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM_CentralAligned_Cmd(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(C1PWMCR_Page);\
        __STATE__==MW_ENABLE?(C1PWMCR = C1PWMCR | PCA1E):(C1PWMCR = C1PWMCR & ~(PCA1E));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief     Enable/Disable PCA1 interrupts
 * @details
 * @param[in] __STATE__ :  Configure PCA1 interrupts
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PCA1_IT_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_IT_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(EIE2 = EIE2 | EPCA1):(EIE2 = EIE2 & ~(EPCA1))

/**
 *******************************************************************************
 * @brief     Enable/Disable PCA1 counter overflow interrupt
 * @details
 * @param[in] __STATE__ :  Configure PCA1 counter overflow interrupt
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PCA1_Counter_IT_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_Counter_IT_Cmd(__STATE__)\
     MWT(\
        __DRV_SFR_PageIndex(C1MOD_Page);\
        __STATE__==MW_ENABLE?(C1MOD = C1MOD | ECF1):(C1MOD = C1MOD & ~(ECF1));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief     Enable/Disable PCA1 module 0 interrupt
 * @details
 * @param[in] __STATE__ :  Configure PCA1 Module 0 interrupts
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PCA1_Module0_IT_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_Module0_IT_Cmd(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(C1CAPM0_Page);\
        __STATE__==MW_ENABLE?(C1CAPM0 = C1CAPM0 | EC1CF0):(C1CAPM0 = C1CAPM0 & ~(EC1CF0));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief     Enable/Disable PCA1 module 1 interrupt
 * @details
 * @param[in] __STATE__ :  Configure PCA1 Module 1 interrupts
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PCA1_Module1_IT_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_Module1_IT_Cmd(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(C1CAPM1_Page);\
        __STATE__==MW_ENABLE?(C1CAPM1 = C1CAPM1 | EC1CF1):(C1CAPM1 = C1CAPM1 & ~(EC1CF1));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Initializes the PCA1 base unit for PWM with dead time according to the specified
 * @details
 * @param[in]   __CKSRC__ : specifies PCA1 clock selection
 *  @arg\b      PCA1_CK_SYSCLK_DIV_12 : PCA1 clock source by system clock with divider 12
 *  @arg\b      PCA1_CK_SYSCLK_DIV_2 : PCA1 clock source by system clock with divider 2
 *  @arg\b      PCA1_CK_T0OF : PCA1 clock source by timer0 overflow
 *  @arg\b      PCA1_CK_EC1I : PCA1 clock source by EC1I pin
 *  @arg\b      PCA1_CK_CKMX16 : PCA1 clock source by CKMIX16
 *  @arg\b      PCA1_CK_SYSCLK_DIV_1 : PCA1 clock source by system clock
 *  @arg\b      PCA1_CK_S0TOF : PCA1 clock source by S0BRG overflow
 *  @arg\b      PCA1_CK_MCKDO : PCA1 clock source by MCK divider output
 * @param[in]   __PERIOD__ : specifies PCA1 period (0~65536)
 * @param[in]   __DTCKSRC__ : specifies Dead Time counter
 *  @arg\b      PCA1_DTCK_SYSTEM_DIV_1 : Clock Pre-Scaler of Dead Time counter by system clock
 *  @arg\b      PCA1_DTCK_SYSTEM_DIV_2 : Clock Pre-Scaler of Dead Time counter by system clock with divider 2
 *  @arg\b      PCA1_DTCK_SYSTEM_DIV_4 : Clock Pre-Scaler of Dead Time counter by system clock with divider 4
 *  @arg\b      PCA1_DTCK_SYSTEM_DIV_8 : Clock Pre-Scaler of Dead Time counter by system clock with divider 8
 * @param[in]   __DTPERIOD__ : specifies Dead-Time period (0~63)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_PWM_DTG_Init(PCA1_CK_SYSCLK_DIV_2,1023,PCA1_DTCK_SYSTEM_DIV_1,2);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PCA1_Dead_Time_Control_definition
#define PCA1_DTCK_SYSTEM_DIV_1          (0x00)
#define PCA1_DTCK_SYSTEM_DIV_2          (DTPS0)
#define PCA1_DTCK_SYSTEM_DIV_4          (DTPS1)
#define PCA1_DTCK_SYSTEM_DIV_8          (DTPS1 | DTPS0)
/// @endcond

#define __DRV_PCA1_PWM_DTG_Init(__CKSRC__,__PERIOD__,__DTCKSRC__,__DTPERIOD__)\
      MWT(\
        __DRV_PCA1_Disable();\
        __DRV_SFR_PageIndex(CH1_Page);\
        CH1 = 0; CH1RL = HIBYTE(65536-(__PERIOD__));\
        CL1 = 0; CL1RL = LOBYTE(65536-(__PERIOD__));\
        __DRV_PCA1_ClockSource_Select(__CKSRC__);\
        __DRV_SFR_PageIndex(C1PDTCR_Page);\
        C1PDTCR = __DTCKSRC__ | (__DTPERIOD__ & 0x3F);\
        __DRV_SFR_PageIndex(0);\
        )


/**
 *******************************************************************************
 * @brief      Starts the PCA1 PWM with dead time channel 0 and channel 1 PWM output.
 * @details
 * @param[in]  __RES__ : PWMn Resolution Setting
 * @arg\b      PCA1_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b      PCA1_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b      PCA1_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b      PCA1_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]  __DUTY__ : specifies PCA1 duty cycle(0~65535)
 * @return     None
 * @note
 * @par        Example
 * @code
 *    __DRV_PCA1_PWM01_DTG_Start(PCA1_PWM_8BIT,254);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM01_DTG_Start(__RES__,__DUTY__)\
      MWT(\
        __DRV_SFR_PageIndex(C1PWM0_Page);\
        __RES__==PCA1_PWM_8BIT?(C1CAP0H = C1CAP1H = LOBYTE(__DUTY__)):(C1CAP0H = (C1CAP1H = HIBYTE(__DUTY__)));\
        C1CAP0L = C1CAP1L = LOBYTE(__DUTY__);\
        C1PWM0 = (C1PWM0 & ~(P0RS11 | P0RS01))|__RES__;\
        C1PWM1 = (C1PWM1 & ~(P1RS11 | P1RS01))|__RES__;\
        C1MOD = C1MOD | BME01;\
        C1CAPM0 = (ECOM01  | PWM01 | DT1E0);\
        C1CAPM1 = (ECOM11  | PWM11 );\
        __DRV_PCA1_Enable();\
        )

/**
 *******************************************************************************
 * @brief       Stop the PCA1 PWM with dead time channel 0 and channel 1 measurement.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_PWM01_DTG_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM01_DTG_Stop()\
      MWT(\
        __DRV_SFR_PageIndex(C1CAPM0_Page);\
        C1CAPM0 = C1CAPM0 & 0x01;\
        C1CAPM1 = C1CAPM1 & 0x01;\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Update the PCA1 channel 0 duty.
 * @details
 * @param[in]   __DUTY__ : specifies PCA1 Channel 0 duty cycle Value
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_SetPWM0DutyValue(256);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_SetPWM0DutyValue(__DUTY__)\
      MWT(\
        __DRV_SFR_PageIndex(C1CAP0H_Page);\
        C1CAP0H = HIBYTE(__DUTY__);\
        C1CAP0L = LOBYTE(__DUTY__);\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Update the PCA1 channel 1 duty.
 * @details
 * @param[in]   __DUTY__ : specifies PCA1 Channel 1 duty cycle Value
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_SetPWM1DutyValue(256);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_SetPWM1DutyValue(__DUTY__)\
      MWT(\
        __DRV_SFR_PageIndex(C1CAP1H_Page);\
        C1CAP1H = HIBYTE(__DUTY__);\
        C1CAP1L = LOBYTE(__DUTY__);\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PCA1 Dead Time period
 * @details
 * @param[in]   __DTCKSRC__ : specifies Dead Time counter
 *  @arg\b      PCA1_DTCK_SYSTEM_DIV_1 : Clock Pre-Scaler of Dead Time counter by system clock
 *  @arg\b      PCA1_DTCK_SYSTEM_DIV_2 : Clock Pre-Scaler of Dead Time counter by system clock with divider 2
 *  @arg\b      PCA1_DTCK_SYSTEM_DIV_4 : Clock Pre-Scaler of Dead Time counter by system clock with divider 4
 *  @arg\b      PCA1_DTCK_SYSTEM_DIV_8 : Clock Pre-Scaler of Dead Time counter by system clock with divider 8
 * @param[in]   __DTPERIOD__ : specifies Dead-Time period (0~63)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_PWM_DTG_period(PCA1_DTCK_SYSTEM_DIV_1,2);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM_DTG_period(__DTCKSRC__,__DTPERIOD__)\
      MWT(\
        __DRV_SFR_PageIndex(C1PDTCR_Page);\
        C1PDTCR = __DTCKSRC__ | (__DTPERIOD__ & 0x3F);\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PCA1 C1EX1 Pin
 * @details
 * @param[in]   __STATE__ : specifies C1EX1 Port pin
 *  @arg\b      C1EX1_P61 : C1EX1=P61 (Default)
 *  @arg\b      C1EX1_P31 : C1EX1=P31
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_C1EX1_PinMux_Select(C1EX1_P31);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PCA1_C1EX1_Pin_select
#define C1EX1_P61     (0x00)
#define C1EX1_P31     (0x01)
/// @endcond

#define __DRV_PCA1_C1EX1_PinMux_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(AUXR17_Page);\
        __STATE__==C1EX1_P31?(AUXR17 = AUXR17 | C1OPS1):(AUXR17 = AUXR17 & ~(C1OPS1));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PCA1 C1EX0 Pin
 * @details
 * @param[in]   __STATE__ : specifies C1EX0 Port pin
 *  @arg\b      C1EX0_P60 : C1EX0=P60 (Default)
 *  @arg\b      C1EX0_P30 : C1EX0=P30
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_C1EX0_PinMux_Select(C1EX0_P30);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PCA1_C1EX0_Pin_select
#define C1EX0_P60     (0x00)
#define C1EX0_P30     (0x01)
/// @endcond

#define __DRV_PCA1_C1EX0_PinMux_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(AUXR17_Page);\
        __STATE__==C1EX0_P30?(AUXR17 = AUXR17 | C1OPS0):(AUXR17 = AUXR17 & ~(C1OPS0));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PCA1 Channel 0 input port Pin
 * @details
 * @param[in]   __STATE__ : specifies C1EX0 capture input Port pin
 *  @arg\b      FROM_C1EX0 : Input by C1EX0 (Default)
 *  @arg\b      FROM_T3EXI : From Timer 3 module
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_IC0_InputSource_Select(FROM_T3EXI);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_Channel0_input_Pin_select
#define FROM_C1EX0 (0x00)
#define FROM_T3EXI (0x01)
/// @endcond

#define __DRV_PCA1_IC0_InputSource_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(AUXR8_Page);\
        __STATE__==FROM_T3EXI?(AUXR8 = AUXR8 | C1ICS0):(AUXR8 = AUXR8 & ~(C1ICS0));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PCA1 Channel 1 input port Pin
 * @details
 * @param[in]   __STATE__ : specifies C1EX1 capture input Port pin
 *  @arg\b      FROM_C1EX1 : Input by C1EX1 (Default)
 *  @arg\b      FROM_T2EXI : From Timer 2 module
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_IC1_InputSource_Select(FROM_T2EXI);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_Channel1_input_Pin_select
#define FROM_C1EX1 (0x00)
#define FROM_T2EXI (0x01)
/// @endcond

#define __DRV_PCA1_IC1_InputSource_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(AUXR8_Page);\
        __STATE__==FROM_T2EXI?(AUXR8 = AUXR8 | C1ICS1):(AUXR8 = AUXR8 & ~(C1ICS1));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PCA1 Clock Output port pin Selection.
 * @details
 * @param[in]   __STATE__ : specifies C1CKO Port pin
 *  @arg\b      C1CKO_P47 : C1CKO=P47 (Default)
 *  @arg\b      C1CKO_P33 : C1CKO=P33
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_C1CKO_PinMux_Select(C1CKO_P33);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_C1CKO_Pin_select
#define C1CKO_P47 (0x00)
#define C1CKO_P33 (0x01)
/// @endcond

#define __DRV_PCA1_C1CKO_PinMux_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(AUXR5_Page);\
        __STATE__==C1CKO_P33?(AUXR5 = AUXR5 | C1COPS):(AUXR5 = AUXR5 & ~(C1COPS));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PCA1 EC1I port pin Selection.
 * @details
 * @param[in]   __STATE__ : specifies EC1I Port pin
 *  @arg\b      EC1I_ECI : Same as PTM0 module ECI setting (Default)
 *  @arg\b      EC1I_P15 : EC1I=P15
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_EC1I_PinMux_Select(EC1I_P15);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_EC1I_Pin_select
#define EC1I_ECI (0x00)
#define EC1I_P15 (0x01)
/// @endcond

#define __DRV_PCA1_EC1I_PinMux_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(AUXR5_Page);\
        __STATE__==EC1I_P15?(AUXR5 = AUXR5 | EC1IPS0):(AUXR5 = AUXR5 & ~(EC1IPS0));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure PCA1 PWM Break Mode
 * @details
 * @param[in]   __STATE__ : PWM break mode is latched or cycle-by-cycle.
 *  @arg\b      LATCH : Latched Mode. (Default)
 *  @arg\b      CYCLE : Cycle-by-cycle Mode
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_PWM_BreakMode_Select(CYCLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM_BreakMode_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(C1PWMCR_Page);\
        __STATE__==CYCLE?(C1PWMCR = C1PWMCR | C1BKM):(C1PWMCR = C1PWMCR & ~(C1BKM));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure PCA1 PWM center aligned flag position.
 * @details
 * @param[in]   __STATE__ : PWM center aligned flag position.
 *  @arg\b      PCA1_PWM_TOP : C1F is set on the top of central aligned PWM cycle. (Default)
 *  @arg\b      PCA1_PWM_BOTTOM : C1F is set on the bottom of central aligned PWM cycle.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_PWM_CentralAlignedFlag_Select(PCA1_PWM_BOTTOM);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PWM_overflow_flag
#define PCA1_PWM_TOP (0x00)
#define PCA1_PWM_BOTTOM (0x01)
/// @endcond

#define __DRV_PCA1_PWM_CentralAlignedFlag_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(C1PWMCR_Page);\
        __STATE__==PCA1_PWM_BOTTOM?(C1PWMCR = C1PWMCR | C1OFS):(C1PWMCR = C1PWMCR & ~(C1OFS));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief     Enable/Disable PCA1 clock output
 * @details   Enable PCA1 clock output with PCA1 base timer overflow rate/2.
 * @param[in] __STATE__ : Configure PCA1 clock output
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PCA1_SetClockOutput(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_SetClockOutput(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(AUXR7_Page);\
        __STATE__==MW_ENABLE?(AUXR7 = AUXR7 | C1CKOE):(AUXR7 = AUXR7 & ~(C1CKOE));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure PCA1 PWM Break Source 0
 * @details
 * @param[in]   __STATE__ : PWM break Source0 select.
 *  @arg\b      BREAK0_DISABLE : Disable break Source0 (Default)
 *  @arg\b      BREAK0_AC0OUT : AC0 Output
 *  @arg\b      BREAK0_INT1ET : nINT1 active
 *  @arg\b      BREAK0_T2EXI : T2EXI(from Timer2)
 *  @arg\b      BREAK0_KBIET :  KBI match active
 *  @arg\b      BREAK0_AC1OUT : AC1 Output
 *  @arg\b      BREAK0_INT3ET : nINT3 active
 *  @arg\b      BREAK0_ADCWI : ADC window detect flag
 * @return      None
 * @note        This function is only active on C1EXn output mode (n=0~1).
 * @par         Example
 * @code
 *    __DRV_PCA1_PWM_BreakSource0_Select(BREAK0_AC0OUT);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM_BreakSource0_Select(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(C1PWMCR_Page);\
        C1PWMCR = (C1PWMCR & ~(C1BKE02|C1BKE01|C1BKE00)) | __STATE__;\
        __DRV_SFR_PageIndex(0);\
       )

/**
 *******************************************************************************
 * @brief       Configure PCA1 PWM Break Source 1
 * @details
 * @param[in]   __STATE__ : PWM break Source1 select.
 *  @arg\b      BREAK1_DISABLE : Disable break Source1 (Default)
 *  @arg\b      BREAK1_INT2ET : nINT2 active
 *  @arg\b      BREAK1_T3EXI : T3EXI(from Timer3)
 *  @arg\b      BREAK1_OP1ES : OP1ES active
 * @return      None
 * @note        This function is only active on C1EXn output mode (n=0~1).
 * @par         Example
 * @code
 *    __DRV_PCA1_PWM_BreakSource1_Select(Break1_INT2ET);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PCA1_Break_Source1_select
#define BREAK1_OP1ES   (C1BKE11|C1BKE10)
/// @endcond

#define __DRV_PCA1_PWM_BreakSource1_Select(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(C1PWMCR_Page);\
        C1PWMCR = (C1PWMCR & ~(C1BKE11|C1BKE10)) | __STATE__;\
        __DRV_SFR_PageIndex(0);\
       )

/**
 *******************************************************************************
 * @brief       Set PCA1 PWM 0 extened 9th bit(MSB bit), associated with C1CAPnL to become a 9-bit resgister used in PWM mode.(C1CAP0L)
 * @param[in]   __VALUE__: PWM 9th bit value is 0 or 1
 *  @arg\b      Value : 0~1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_SetPWM0DutyValue9thLow(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_SetPWM0DutyValue9thLow(__VALUE__)\
    MWT(\
        __DRV_SFR_PageIndex(C1PWM0_Page);\
        __VALUE__==0?(C1PWM0 = C1PWM0 & ~(ECAP0L1)):(C1PWM0 = C1PWM0 | (ECAP0L1));\
        __DRV_SFR_PageIndex(0);\
       )
/**
 *******************************************************************************
 * @brief       Set PCA1 PWM 1 extened 9th bit(MSB bit), associated with C1CAPnL to become a 9-bit resgister used in PWM mode.(C1CAP1L)
 * @param[in]   __VALUE__: PWM 9th bit value is 0 or 1
 *  @arg\b      Value : 0~1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_SetPWM1DutyValue9thLow(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_SetPWM1DutyValue9thLow(__VALUE__)\
    MWT(\
        __DRV_SFR_PageIndex(C1PWM1_Page);\
        __VALUE__==0?(C1PWM1 = C1PWM1 & ~(ECAP1L1)):(C1PWM1 = C1PWM1 | ECAP1L1);\
        __DRV_SFR_PageIndex(0);\
       )

/**
 *******************************************************************************
 * @brief       Set PCA1 PWM 0 extened 9th bit(MSB bit), associated with C1CAPnH to become a 9-bit resgister used in PWM mode.(C1CAP0H)
 * @param[in]   __VALUE__: PWM 9th bit value is 0 or 1
 *  @arg\b      Value : 0~1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_SetPWM0DutyValue9thHigh(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_SetPWM0DutyValue9thHigh(__VALUE__)\
    MWT(\
        __DRV_SFR_PageIndex(C1PWM0_Page);\
        __VALUE__==0?(C1PWM0 = C1PWM0 & ~(ECAP0H1)):(C1PWM0 = C1PWM0 | ECAP0H1);\
        __DRV_SFR_PageIndex(0);\
       )

/**
 *******************************************************************************
 * @brief       Set PCA1 PWM 1 extened 9th bit(MSB bit), associated with C1CAPnH to become a 9-bit resgister used in PWM mode.(C1CAP1H)
 * @param[in]   __VALUE__: PWM 9th bit value is 0 or 1
 *  @arg\b      Value : 0~1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_SetPWM1DutyValue9thHigh(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_SetPWM1DutyValue9thHigh(__VALUE__)\
    MWT(\
        __DRV_SFR_PageIndex(C1PWM1_Page);\
        __VALUE__==0?(C1PWM1 = C1PWM1 & ~(ECAP1H1)):(C1PWM1 = C1PWM1 | ECAP1H1);\
        __DRV_SFR_PageIndex(0);\
       )

/**
 *******************************************************************************
 * @brief       Set PCA1 PWM0 resolution
 * @param[in]   __VALUE__: PCA1 PWM0 resolution
 *  @arg\b      PCA1_PWM_8BIT : 8 bit PWMn, the overflow is active when [CH1, CL1] counts XXXX-XXXX-1111-1111 -> XXXX-XXXX-0000-0000.
 *  @arg\b      PCA1_PWM_10BIT : 10 bit PWMn, the overflow is active when [CH1, CL1] counts XXXX-XX11-1111-1111 -> XXXX-XX00-0000-0000.
 *  @arg\b      PCA1_PWM_12BIT : 12 bit PWMn, the overflow is active when [CH1, CL1] counts XXXX-1111-1111-1111 -> XXXX-0000-0000-0000.
 *  @arg\b      PCA1_PWM_16BIT : 16 bit PWMn, the overflow is active when [CH1, CL1] counts 1111-1111-1111-1111 -> 0000-0000-0000-0000.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_PWM0Resolution_Select(PCA1_PWM_8BIT);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM0Resolution_Select(__VALUE__)\
    MWT(\
        __DRV_SFR_PageIndex(C1PWM0_Page);\
        C1PWM0 = (C1PWM0 & ~(P0RS11 | P0RS01)) | __VALUE__;\
        __DRV_SFR_PageIndex(0);\
       )

/**
 *******************************************************************************
 * @brief       Set PCA1 PWM1 resolution
 * @param[in]   __VALUE__: PCA1 PWM1 resolution
 *  @arg\b      PCA1_PWM_8BIT : 8 bit PWMn, the overflow is active when [CH1, CL1] counts XXXX-XXXX-1111-1111 -> XXXX-XXXX-0000-0000.
 *  @arg\b      PCA1_PWM_10BIT : 10 bit PWMn, the overflow is active when [CH1, CL1] counts XXXX-XX11-1111-1111 -> XXXX-XX00-0000-0000.
 *  @arg\b      PCA1_PWM_12BIT : 12 bit PWMn, the overflow is active when [CH1, CL1] counts XXXX-1111-1111-1111 -> XXXX-0000-0000-0000.
 *  @arg\b      PCA1_PWM_16BIT : 16 bit PWMn, the overflow is active when [CH1, CL1] counts 1111-1111-1111-1111 -> 0000-0000-0000-0000.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_PWM1Resolution_Select(PCA1_PWM_8BIT);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_PWM1Resolution_Select(__VALUE__)\
    MWT(\
        __DRV_SFR_PageIndex(C1PWM1_Page);\
        C1PWM1 = (C1PWM1 & ~(P1RS11 | P1RS01)) | __VALUE__;\
        __DRV_SFR_PageIndex(0);\
       )

/**
 *******************************************************************************
 * @brief       Configure C1POEn control Mode
 * @details
 * @param[in]   __STATE__ : C1POEn control is CPU writing or PWM cycle.
 *  @arg\b      CPU_WRITING : C1POEn function is active immediately after CPU writing. (Default)
 *  @arg\b      PWM_CYCLE : C1POEn function is aligned to PWM cycle.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PCA1_C1POEnControl_Select(PWM_CYCLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PCA1_C1POEnControl_Select(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(C1AOE1_Page);\
        __STATE__==PWM_CYCLE?(C1AOE1 = C1AOE1 | C1POEM0):(C1AOE1 = C1AOE1 & ~(C1POEM0));\
        __DRV_SFR_PageIndex(0);\
       )

/**
*******************************************************************************
* @brief       Get PCA1 Module 0 flag.
* @details     Set by hardware when a match or capture occurs.
* @return      Data type bit
* @note        None
* @par         Example
* @code
     __DRV_PCA1_Module0_GetFlag(user_define);
* @endcode
*******************************************************************************
*/
#define __DRV_PCA1_Module0_GetFlag(__VALUE__)\
    MWT(\
        __DRV_SFR_PageIndex(C1CON_Page);\
        __VALUE__= C1CF0;\
        __DRV_SFR_PageIndex(0);\
       )

/**
*******************************************************************************
* @brief       Get PCA1 Module 1 flag.
* @details     Set by hardware when a match or capture occurs.
* @return      Data type bit
* @note        None
* @par         Example
* @code
     __DRV_PCA1_Module1_GetFlag(user_define);
* @endcode
*******************************************************************************
*/
#define __DRV_PCA1_Module1_GetFlag(__VALUE__)\
    MWT(\
        __DRV_SFR_PageIndex(C1CON_Page);\
        __VALUE__= C1CF1;\
        __DRV_SFR_PageIndex(0);\
       )

bool DRV_PCA1_GetModule0Flag(void);
bool DRV_PCA1_GetModule1Flag(void);
bool DRV_PCA1_GetOverflowFlag(void);
bool DRV_PCA1_GetBreakFlag(void);
uint16_t DRV_PCA1_GetPWM0DutyValue(void);
uint16_t DRV_PCA1_GetPWM1DutyValue(void);
#endif
