/**
 ******************************************************************************
 *
 * @file        MG82F6P32_OPA1_DRV.h
 *
 * @brief       This is the C code format driver head file.
 *
 * @par         Project
 *              MG82F6P32
 * @version     v1.00
 * @date        2024/03/26
 * @copyright   Copyright (c) 2019 Megawin Technology Co., Ltd.
 *              All rights reserved.
 *
 ******************************************************************************
 * @par         Disclaimer
 *      The Demo software is provided "AS IS" without any warranty, either
 *      expressed or implied, including, but not limited to, the implied warranties
 *      of merchantability and fitness for a particular purpose. The author will
 *      not be liable for any special, incidental, consequential or indirect
 *      damages due to loss of data or any other reason.
 *      These statements agree with the world wide and local dictated laws about
 *      authorship and violence against these laws.
 ******************************************************************************
 ******************************************************************************
 */
#ifndef _MG82F6P32_PGA_DRV_H
#define _MG82F6P32_PGA_DRV_H
/**
 *******************************************************************************
 * @brief       MW_ENABLE/MW_DISABLE PGA block
 * @details     Set PGEN
 * @param[in]   __STATE__  : 
 *  @arg\b      MW_ENABLE   :Set to turn on the PGA block. At least 5us stable time after PGA is enabled.
 *  @arg\b      MW_DISABLE  :Clear to turn off the PGA block.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PGA_PGEN_Block(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PGA_PGEN_Block(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(PGACON0_Page);\
        (__STATE__==MW_ENABLE?(PGACON0 = PGACON0 |PGEN):(PGACON0 = PGACON0 & (~PGEN)));\
        __DRV_SFR_PageIndex(0);\
    )
/**
  *******************************************************************************
 * @brief     Select PGA PowerMode
 * @details   Set PGLP
 * @param[in] __STATE__  :  
 *  @arg\b    MW_ENABLE   :PGA works under low power mode.
 *  @arg\b    MW_DISABLE  :PGA works under normal power mode.(Default)
 * @return    none
 * @note
 * @par       Example
 * @code
 *    __DRV_PGA_PGLP_Select(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PGA_PGLP_Select(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(PGACON0_Page);\
        (__STATE__==MW_ENABLE?(PGACON0 = (PGACON0 |PGLP)):(PGACON0 = PGACON0 & (~PGLP)));\
        __DRV_SFR_PageIndex(0);\
    )
/**
  *******************************************************************************
 * @brief      MW_ENABLE/MW_DISABLE PGA Output
 * @details    Set PGAOE
 * @param[in]  __STATE__  :  
 *  @arg\b     MW_ENABLE   :Disconnect from I/O.(Default)
 *  @arg\b     MW_DISABLE  :Connect to PGO pin.
 * @return     none
 * @note
 * @par        Example
 * @code
 *    __DRV_PGA_PGLP_Select(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PGA_PGAOE_Select(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(PGACON0_Page);\
        __STATE__==MW_ENABLE?(PGACON0 = (PGACON0 |PGAOE)):(PGACON0 = PGACON0 & (~PGAOE));\
        __DRV_SFR_PageIndex(0);\
    )
/**
*******************************************************************************
 * @brief       Select PGA positive input path
 * @details     Set PGPIS1 PGPIS0
 * @param[in]   __SELECT__ : config positive pin 
 *  @arg\b      PGA_PGPIS0 : PI select Internal 1.2V reference voltage.(default)
 *  @arg\b      PGA_PGPIS1 : PI select AGND.
 *  @arg\b      PGA_PGPIS2 : PI select AIN (From ADC AMUX output).
 *  @arg\b      PGA_PGPIS3 : PI select OP0PI (P3.0).
 * @return      none
 * @note
 * @par         Example
 * @code
 *    __DRV_PGA_PositivePinMux_Select(PGA_PGPIS0);
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_PGA_PositivePinMux_Select
#define PGA_PGPIS0 ~(PGPIS1|PGPIS0)     /*!< PI select Internal 1.2V reference voltage_ */
#define PGA_PGPIS1 PGPIS0               /*!< PI select AGND  */
#define PGA_PGPIS2 PGPIS1               /*!< PI select AIN (From ADC AMUX output)  */
#define PGA_PGPIS3 (PGPIS1|PGPIS0)      /*!< PI select OP0PI (P3.0)  */
/// @endcond

#define __DRV_PGA_PositivePinMux_Select(__SELECT__)\
    MWT(\
        __DRV_SFR_PageIndex(PGACON0_Page);\
        PGACON0 = (PGACON0 & ~(PGPIS1 | PGPIS0));\
        PGACON0 = (PGACON0| (__SELECT__&(PGPIS1 | PGPIS0)));\
        __DRV_SFR_PageIndex(0);\
    )
/**
*******************************************************************************
 * @brief     Select PGA First &Second stage gain control
 * @details   Set PGENS1GN PGGNM PGGAIN2 PGGAIN1 PGGAIN0
 * @param[in]   __SELECT__   : config PGA 1st&2ed(total) gain stage gain control.
 *  @arg\b      PGA_PGGAIN01 : PGA 2nd select x1. (Default)
 *  @arg\b      PGA_PGGAIN02 : PGA 2nd select x2.
 *  @arg\b      PGA_PGGAIN04 : PGA 2nd select x4.
 *  @arg\b      PGA_PGGAIN08 : PGA 2nd select x8.
 *  @arg\b      PGA_PGGAIN16 : PGA 2nd select x16.
 *  @arg\b      PGA_PGGAIN32 : PGA 2nd select x32.
 *  @arg\b      PGA_PGGAIN64 : PGA 2nd select x64.
 *  @arg\b      PGA_PGGAIN128 : PGA 2nd select x128.
 * @return      none
 * @note
 * @par         Example
 * @code
 *    __DRV_PGA_TotalGainControl_Select(PGA_PGGAIN01);
 * @endcode
 *******************************************************************************
 */
/// @cond __DRV_PGA_GainControl_Select
#define PGA_PGGAIN01 ~(PGGN2|PGGN1|PGGN0)           /*!< PGA 2nd select x1 */
#define PGA_PGGAIN02 PGGN0                          /*!< PGA 2nd select x2 */
#define PGA_PGGAIN04 PGGN1                          /*!< PGA 2nd select x4 */
#define PGA_PGGAIN08 (PGGN1|PGGN0)                  /*!< PGA 2nd select x8 */
#define PGA_PGGAIN16 PGGN2                          /*!< PGA 2nd select x16 */
#define PGA_PGGAIN32 (PGENS1GN|PGGNM|PGGN1)         /*!< PGA 1st selcet x8 2nd select x4 */
#define PGA_PGGAIN64 (PGENS1GN|PGGNM|PGGN1|PGGN0)   /*!< PGA 1st selcet x8 2nd select x8 */
#define PGA_PGGAIN128 (PGENS1GN|PGGNM|PGGN2)        /*!< PGA 1st selcet x8 2nd select x16 */
/// @endcond
#define __DRV_PGA_TotalGainControl_Select(__SELECT__)\
    MWT(\
        __DRV_SFR_PageIndex(PGACON1_Page);\
        PGACON1 = (PGACON1 & ~(PGENS1GN|PGGNM|PGGN2|PGGN1|PGGN0));\
        PGACON1 = (PGACON1|(__SELECT__&(PGENS1GN|PGGNM|PGGN2|PGGN1|PGGN0)));\
        __DRV_SFR_PageIndex(0);\
    )
#endif

