/**
 ******************************************************************************
 *
 * @file        MG82F6P32_PTM0_DRV.h
 *
 * @brief       This is the C code format driver head file.
 *
 * @par         Project
 *              MG82F6P32
 * @version     v1.00
 * @date        2024/03/14
 * @copyright   Copyright (c) 2019 MegaWin Technology Co., Ltd.
 *              All rights reserved.
 *
 ******************************************************************************
 * @par         Disclaimer
 *      The Demo software is provided "AS IS" without any warranty, either
 *      expressed or implied, including, but not limited to, the implied warranties
 *      of merchantability and fitness for a particular purpose. The author will
 *      not be liable for any special, incidental, consequential or indirect
 *      damages due to loss of data or any other reason.
 *      These statements agree with the world wide and local dictated laws about
 *      authorship and violence against these laws.
 ******************************************************************************
 ******************************************************************************
 */

#ifndef _MG82F6P32_PTM0_DRV_H
#define _MG82F6P32_PTM0_DRV_H

/**
 *******************************************************************************
 * @brief       Enable the PTM0.
 * @details     PTM0 start count
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_Enable();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Enable()\
        CR = 1;


/**
 *******************************************************************************
 * @brief       Disable the PTM0.
 * @details     PTM0 stop count
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_Disable();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Disable()\
        CR = 0;\

/**
 *******************************************************************************
 * @brief       Configure PTM0 Clock source.
 * @details
 * @param[in]   __CLOCKSRC__ : specifies PTM0 clock selection
 *  @arg\b      PTM0_CK_SYSCLK_DIV_12 : PTM0 clock source by system clock with divider 12.
 *  @arg\b      PTM0_CK_SYSCLK_DIV_2 : PTM0 clock source by system clock with divider 2.
 *  @arg\b      PTM0_CK_T0OF : PTM0 clock source by Timer0 overflow.
 *  @arg\b      PTM0_CK_ECI : PTM0 clock source by ECI pin.
 *  @arg\b      PTM0_CK_CKMX16 : PTM0 clock source by CKMIX16.
 *  @arg\b      PTM0_CK_SYSCLK_DIV_1 : PTM0 clock source by system clock.
 *  @arg\b      PTM0_CK_S0TOF : PTM0 clock source by S0BRG overflow.
 *  @arg\b      PTM0_CK_MCKDO : PTM0 clock source by MCK divider output.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_ClockSource_Select(PTM0_CK_SYSCLK_DIV_1);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PTM0_clock_source_definition
#define PTM0_CK_SYSCLK_DIV_12        (0x0)
#define PTM0_CK_SYSCLK_DIV_2         (CPS0)
#define PTM0_CK_T0OF                 (CPS1)
#define PTM0_CK_ECI                  (CPS1 | CPS0)
#define PTM0_CK_CKMX16               (CPS2)
#define PTM0_CK_SYSCLK_DIV_1         (CPS2 | CPS0)
#define PTM0_CK_S0TOF                (CPS2 | CPS1)
#define PTM0_CK_MCKDO                (CPS2 | CPS1 | CPS0)
/// @endcond

#define __DRV_PTM0_ClockSource_Select(__CLOCKSRC__)\
        CMOD = (CMOD & ~(CPS2 | CPS1 | CPS0)) | __CLOCKSRC__;\


/**
 *******************************************************************************
 * @brief       Set PTM0 counter value
 * @details
 * @param[in]   __VALUE__: PTM0 counter value
 *  @arg\b      Value : 0~65535
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetCounterValue(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetCounterValue(__VALUE__)\
      MWT(\
        CH=HIBYTE(__VALUE__);\
        CL=LOBYTE(__VALUE__);\
        )

/**
 *******************************************************************************
 * @brief       Get PTM0 counter value
 * @details     16bit data from PTM0 counter Value
 * @return      Data type word(16bit)
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_GetCounterValue(16bitReg);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_GetCounterValue(__VALUE__)\
        __VALUE__ = (CH1 << 8 | CL1);\

/**
 *******************************************************************************
 * @brief       Set PTM0 counter reload value
 * @param[in]   __VALUE__: PTM0 counter reload value
 *  @arg\b      Value : 0~65535
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetCounterReloadValue(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetCounterReloadValue(__VALUE__)\
      MWT(\
        CHRL=HIBYTE(__VALUE__);\
        CLRL=LOBYTE(__VALUE__);\
       )

/**
 *******************************************************************************
 * @brief       Get PTM0 counter reload value
 * @details     16bit data from PTM0 counter reload Value
 * @return      Data type word(16bit)
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_GetCounterReloadValue(16bitReg);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_GetCounterReloadValue(__VALUE__)\
        __VALUE__ = (CHRL << 8 | CLRL);\

/**
 *******************************************************************************
 * @brief       Configure the PTM0 module0 output inverted or non-inverted.
 * @details
 * @param[in]   __STATE__: specifies the PWM0 output Inverted
 *  @arg\b      MW_ENABLE : Inverted Compare/PWM output.
 *  @arg\b      MW_DISABLE : Non-inverted Compare/PWM output. (Default)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM0_SetInverse(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM0_SetInverse(__STATE__)\
        __STATE__==MW_ENABLE?(PCAPWM0 = PCAPWM0 | P0INV):(PCAPWM0 = PCAPWM0 & ~(P0INV))

/**
 *******************************************************************************
 * @brief       Configure the PTM0 module1 output inverted or non-inverted.
 * @details
 * @param[in]   __STATE__: specifies the PWM1 output Inverted
 *  @arg\b      MW_ENABLE : Inverted Compare/PWM output.
 *  @arg\b      MW_DISABLE : Non-inverted Compare/PWM output. (Default)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM1_SetInverse(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM1_SetInverse(__STATE__)\
        __STATE__==MW_ENABLE?(PCAPWM1 = PCAPWM1 | P1INV):(PCAPWM1 = PCAPWM1 & ~(P1INV))

/**
 *******************************************************************************
 * @brief       Configure the PTM0 module2 output inverted or non-inverted.
 * @details
 * @param[in]   __STATE__: specifies the PWM2 output Inverted
 *  @arg\b      MW_ENABLE : Inverted Compare/PWM output.
 *  @arg\b      MW_DISABLE : Non-inverted Compare/PWM output. (Default)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM2_SetInverse(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM2_SetInverse(__STATE__)\
        __STATE__==MW_ENABLE?(PCAPWM2 = PCAPWM2 | P2INV):(PCAPWM2 = PCAPWM2 & ~(P2INV))

/**
 *******************************************************************************
 * @brief       Configure the PTM0 module3 output inverted or non-inverted.
 * @details
 * @param[in]   __STATE__: specifies the PWM3 output Inverted
 *  @arg\b      MW_ENABLE : Inverted Compare/PWM output.
 *  @arg\b      MW_DISABLE : Non-inverted Compare/PWM output. (Default)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM3_SetInverse(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM3_SetInverse(__STATE__)\
        __STATE__==MW_ENABLE?(PCAPWM3 = PCAPWM3 | P3INV):(PCAPWM3 = PCAPWM3 & ~(P3INV))

/**
 *******************************************************************************
 * @brief       Configure the PTM0 module4 output inverted or non-inverted.
 * @details
 * @param[in]   __STATE__: specifies the PWM4 output Inverted
 *  @arg\b      MW_ENABLE : Inverted Compare/PWM output.
 *  @arg\b      MW_DISABLE : Non-inverted Compare/PWM output. (Default)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM4_SetInverse(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM4_SetInverse(__STATE__)\
        __STATE__==MW_ENABLE?(PCAPWM4 = PCAPWM4 | P4INV):(PCAPWM4 = PCAPWM4 & ~(P4INV))

/**
 *******************************************************************************
 * @brief       Configure the PTM0 module5 output inverted or non-inverted.
 * @details
 * @param[in]   __STATE__: specifies the PWM5 output Inverted
 *  @arg\b      MW_ENABLE : Inverted Compare/PWM output.
 *  @arg\b      MW_DISABLE : Non-inverted Compare/PWM output. (Default)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM5_SetInverse(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM5_SetInverse(__STATE__)\
        __STATE__==MW_ENABLE?(PCAPWM5 = PCAPWM5 | P5INV):(PCAPWM5 = PCAPWM5 & ~(P5INV))

/**
 *******************************************************************************
 * @brief       DeInitializes the PTM0 peripheral
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_DeInit();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_DeInit()\
      MWT(\
        __DRV_PTM0_Disable();\
        CMOD = 0;\
        )

/**
 *******************************************************************************
 * @brief       PTM0 counter Idle control.
 * @details
 * @param[in]   __STATE__: Specifies PTM0 cannot operate in idle mode
 *  @arg\b      MW_ENABLE : Lets the PTM0 counter be gated off during Idle mode.
 *  @arg\b      MW_DISABLE : Lets the PTM0 counter continue functioning during Idle mode.(Default)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetIdleGateOff(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetIdleGateOff(__STATE__)\
        __STATE__==MW_ENABLE?(CMOD = CMOD | CIDL):(CMOD = CMOD & ~(CIDL))

/**
 *******************************************************************************
 * @brief       Clear the PTM0 overflow interrupt flag.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_Overflow_ClearFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Overflow_ClearFlag()\
        CF = 0;

/**
 *******************************************************************************
 * @brief       Clear the PTM0 PWM break interrupt flag.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_Break_ClearFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Break_ClearFlag()\
        AUXR0 = AUXR0 & ~PBKF;

/**
 *******************************************************************************
 * @brief       Clear the PTM0 modele0 interrupt flag.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_Module0_ClearFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Module0_ClearFlag()\
        CCF0 = 0;

/**
 *******************************************************************************
 * @brief       Clear the PTM0 modele1 interrupt flag.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_Module1_ClearFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Module1_ClearFlag()\
        CCF1 = 0;

/**
 *******************************************************************************
 * @brief       Clear the PTM0 modele2 interrupt flag.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_Module2_ClearFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Module2_ClearFlag()\
        CCF2 = 0;

/**
 *******************************************************************************
 * @brief       Clear the PTM0 modele3 interrupt flag.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_Module3_ClearFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Module3_ClearFlag()\
        CCF3 = 0;

/**
 *******************************************************************************
 * @brief       Clear the PTM0 modele4 interrupt flag.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_Module4_ClearFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Module4_ClearFlag()\
        CCF4 = 0;

/**
 *******************************************************************************
 * @brief       Clear the PTM0 modele5 interrupt flag.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_Module5_ClearFlag();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Module5_ClearFlag()\
        CCF5 = 0;

/**
 *******************************************************************************
 * @brief       Initializes the PTM0 base unit for output compare according to the specified(High Speed Output)
 * @details
 * @param[in]   __CKSRC__ : specifies PTM0 clock selection
 *  @arg\b      PTM0_CK_SYSCLK_DIV_12 : PTM0 clock source by system clock with divider 12
 *  @arg\b      PTM0_CK_SYSCLK_DIV_2 : PTM0 clock source by system clock with divider 2
 *  @arg\b      PTM0_CK_T0OF : PTM0 clock source by timer0 overflow
 *  @arg\b      PTM0_CK_ECI : PTM0 clock source by ECI pin
 *  @arg\b      PTM0_CK_CKMX16 : PTM0 clock source by CKMIX16
 *  @arg\b      PTM0_CK_SYSCLK_DIV_1 : PTM0 clock source by system clock
 *  @arg\b      PTM0_CK_S0TOF : PTM0 clock source by S0BRG overflow
 *  @arg\b      PTM0_CK_MCKDO : PTM0 clock source by MCK divider output
 * @param[in]   __BUFFERED__ : Buffered mode Configure
 *  @arg\b      PTM0_PWM_UNBUFFER : Unbuffered mode
 *  @arg\b      PTM0_PWM01_BUFFER : PWM channel 0 and channel 1 are buffered mode
 *  @arg\b      PTM0_PWM23_BUFFER : PWM channel 2 and channel 3 are buffered mode
 *  @arg\b      PTM0_PWM45_BUFFER : PWM channel 4 and channel 5 are buffered mode
 * @param[in]   __PERIOD__ : specifies PTM0 period (0~65536)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_OC_Init(PTM0_CK_SYSCLK_DIV_2,PTM0_PWM01_BUFFER | PTM0_PWM23_BUFFER, 1023);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PTM0_PWM_buffered_definition
#define PTM0_PWM_UNBUFFER           (0x00)
#define PTM0_PWM01_BUFFER           (BME0)
#define PTM0_PWM23_BUFFER           (BME2)
#define PTM0_PWM45_BUFFER           (BME4)
/// @endcond

#define __DRV_PTM0_OC_Init(__CKSRC__,__BUFFERED__,__PERIOD__)\
      MWT(\
        __DRV_PTM0_Disable();\
        CH = 0; CHRL = HIBYTE(65536-(__PERIOD__));\
        CL = 0; CLRL = LOBYTE(65536-(__PERIOD__));\
        __DRV_PTM0_ClockSource_Select(__CKSRC__);\
        CMOD = CMOD & 0x8F;\
        CMOD = CMOD | (__BUFFERED__&0x70);\
        )

/**
 *******************************************************************************
 * @brief      Starts the PTM0 channel 0 output compare.
 * @details
 * @param[in]  __RES__ : PWMn Resolution Setting
 * @arg\b      PTM0_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b      PTM0_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b      PTM0_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b      PTM0_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]  __VALUE__ : specifies PTM0 Channel 0 compare value(0~65535)
 * @return     None
 * @note
 * @par        Example
 * @code
 *    __DRV_PTM0_OC0_Start(PTM0_PWM_10BIT,256);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PTM0_PWM_Resolution
#define PTM0_PWM_8BIT     (0x00)
#define PTM0_PWM_10BIT    (P0RS0)
#define PTM0_PWM_12BIT    (P0RS1)
#define PTM0_PWM_16BIT    (P0RS1 | P0RS0)
/// @endcond

#define __DRV_PTM0_OC0_Start(__RES__,__VALUE__)\
      MWT(\
        __RES__==PTM0_PWM_8BIT?(CCAP0H = LOBYTE(__VALUE__)):(CCAP0H = HIBYTE(__VALUE__));\
        CCAP0L = LOBYTE(__VALUE__);\
         PCAPWM0 = (PCAPWM0 & ~(P0RS1 | P0RS0)) | __RES__;\
        CCAPM0 = (ECOM0 | TOG0 | MAT0);\
        __DRV_PTM0_Enable();\
        )

/**
 *******************************************************************************
 * @brief      Starts the PTM0 channel 1 output compare.
 * @details
 * @param[in]  __RES__ : PWMn Resolution Setting
 * @arg\b      PTM0_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b      PTM0_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b      PTM0_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b      PTM0_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]  __VALUE__ : specifies PTM0 Channel 1 compare value(0~65535)
 * @return     None
 * @note
 * @par        Example
 * @code
 *    __DRV_PTM0_OC1_Start(PTM0_PWM_10BIT,256);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_OC1_Start(__RES__,__VALUE__)\
      MWT(\
        __RES__==PTM0_PWM_8BIT?(CCAP1H = LOBYTE(__VALUE__)):(CCAP1H = HIBYTE(__VALUE__));\
        CCAP1L = LOBYTE(__VALUE__);\
        PCAPWM1 = (PCAPWM1 & ~(P0RS1 | P0RS0)) | __RES__;\
        CCAPM1 = (ECOM0 | TOG0 | MAT0);\
        __DRV_PTM0_Enable();\
        )

/**
 *******************************************************************************
 * @brief      Starts the PTM0 channel 2 output compare.
 * @details
 * @param[in]  __RES__ : PWMn Resolution Setting
 * @arg\b      PTM0_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b      PTM0_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b      PTM0_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b      PTM0_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]  __VALUE__ : specifies PTM0 Channel 2 compare value(0~65535)
 * @return     None
 * @note
 * @par        Example
 * @code
 *    __DRV_PTM0_OC2_Start(PTM0_PWM_10BIT,256);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_OC2_Start(__RES__,__VALUE__)\
      MWT(\
        __RES__==PTM0_PWM_8BIT?(CCAP2H = LOBYTE(__VALUE__)):(CCAP2H = HIBYTE(__VALUE__));\
        CCAP2L = LOBYTE(__VALUE__);\
        PCAPWM2 = (PCAPWM2 & ~(P0RS1 | P0RS0)) | __RES__;\
        CCAPM2 = (ECOM0 | TOG0 | MAT0);\
        __DRV_PTM0_Enable();\
        )

/**
 *******************************************************************************
 * @brief      Starts the PTM0 channel 3 output compare.
 * @details
 * @param[in]  __RES__ : PWMn Resolution Setting
 * @arg\b      PTM0_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b      PTM0_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b      PTM0_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b      PTM0_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]  __VALUE__ : specifies PTM0 Channel 3 compare value(0~65535)
 * @return     None
 * @note
 * @par        Example
 * @code
 *    __DRV_PTM0_OC3_Start(PTM0_PWM_10BIT,256);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_OC3_Start(__RES__,__VALUE__)\
      MWT(\
        __RES__==PTM0_PWM_8BIT?(CCAP3H = LOBYTE(__VALUE__)):(CCAP3H = HIBYTE(__VALUE__));\
        CCAP3L = LOBYTE(__VALUE__);\
        PCAPWM3 = (PCAPWM3 & ~(P0RS1 | P0RS0)) | __RES__;\
        CCAPM3 = (ECOM0 | TOG0 | MAT0);\
        __DRV_PTM0_Enable();\
        )

/**
 *******************************************************************************
 * @brief      Starts the PTM0 channel 4 output compare.
 * @details
 * @param[in]  __RES__ : PWMn Resolution Setting
 * @arg\b      PTM0_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b      PTM0_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b      PTM0_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b      PTM0_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]  __VALUE__ : specifies PTM0 Channel 4 compare value(0~65535)
 * @return     None
 * @note
 * @par        Example
 * @code
 *    __DRV_PTM0_OC4_Start(PTM0_PWM_10BIT,256);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_OC4_Start(__RES__,__VALUE__)\
      MWT(\
        __RES__==PTM0_PWM_8BIT?(CCAP4H = LOBYTE(__VALUE__)):(CCAP4H = HIBYTE(__VALUE__));\
        CCAP4L = LOBYTE(__VALUE__);\
        PCAPWM4 = (PCAPWM4 & ~(P0RS1 | P0RS0)) | __RES__;\
        CCAPM4 = (ECOM0 | TOG0 | MAT0);\
        __DRV_PTM0_Enable();\
        )

/**
 *******************************************************************************
 * @brief      Starts the PTM0 channel 5 output compare.
 * @details
 * @param[in]  __RES__ : PWMn Resolution Setting
 * @arg\b      PTM0_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b      PTM0_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b      PTM0_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b      PTM0_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]  __VALUE__ : specifies PTM0 Channel 5 compare value(0~65535)
 * @return     None
 * @note
 * @par        Example
 * @code
 *    __DRV_PTM0_OC5_Start(PTM0_PWM_10BIT,256);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_OC5_Start(__RES__,__VALUE__)\
      MWT(\
        __RES__==PTM0_PWM_8BIT?(CCAP5H = LOBYTE(__VALUE__)):(CCAP5H = HIBYTE(__VALUE__));\
        CCAP5L = LOBYTE(__VALUE__);\
        PCAPWM5 = (PCAPWM5 & ~(P0RS1 | P0RS0)) | __RES__;\
        CCAPM5 = (ECOM0 | TOG0 | MAT0);\
        __DRV_PTM0_Enable();\
        )

/**
 *******************************************************************************
 * @brief       Stop the PTM0 output compare channel 0.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_OC0_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_OC0_Stop()\
        (CCAPM0 &= 0x01)

/**
 *******************************************************************************
 * @brief       Stop the PTM0 output compare channel 1.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_OC1_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_OC1_Stop()\
        (CCAPM1 &= 0x01)

/**
 *******************************************************************************
 * @brief       Stop the PTM0 output compare channel 2.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_OC2_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_OC2_Stop()\
        (CCAPM2 &= 0x01)

/**
 *******************************************************************************
 * @brief       Stop the PTM0 output compare channel 3.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_OC3_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_OC3_Stop()\
        (CCAPM3 &= 0x01)

/**
 *******************************************************************************
 * @brief       Stop the PTM0 output compare channel 4.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_OC4_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_OC4_Stop()\
        (CCAPM4 &= 0x01)

/**
 *******************************************************************************
 * @brief       Stop the PTM0 output compare channel 5.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_OC5_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_OC5_Stop()\
        (CCAPM5 &= 0x01)

/**
 *******************************************************************************
 * @brief       Initializes the PTM0 base unit for PWM according to the specified
 * @details
 * @param[in]   __CKSRC__ : specifies PTM0 clock selection
 *  @arg\b      PTM0_CK_SYSCLK_DIV_12 : PTM0 clock source by system clock with divider 12
 *  @arg\b      PTM0_CK_SYSCLK_DIV_2 : PTM0 clock source by system clock with divider 2
 *  @arg\b      PTM0_CK_T0OF : PTM0 clock source by timer0 overflow
 *  @arg\b      PTM0_CK_ECI : PTM0 clock source by ECI pin
 *  @arg\b      PTM0_CK_CKMX16 : PTM0 clock source by CKMIX16
 *  @arg\b      PTM0_CK_SYSCLK_DIV_1 : PTM0 clock source by system clock
 *  @arg\b      PTM0_CK_S0TOF : PTM0 clock source by S0BRG overflow
 *  @arg\b      PTM0_CK_MCKDO : PTM0 clock source by MCK divider output
 * @param[in]   __BUFFERED__ : Buffered mode Configure
 *  @arg\b      PTM0_PWM_UNBUFFER : Unbuffered mode
 *  @arg\b      PTM0_PWM01_BUFFER : PWM channel 0 and channel 1 are buffered mode
 *  @arg\b      PTM0_PWM23_BUFFER : PWM channel 2 and channel 3 are buffered mode
 *  @arg\b      PTM0_PWM45_BUFFER : PWM channel 4 and channel 5 are buffered mode
 * @param[in]   __PERIOD__ : specifies PTM0 period (0~65536)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM_Init(PTM0_CK_SYSCLK_DIV_2,PTM0_PWM01_BUFFER | PTM0_PWM23_BUFFER, 1023);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM_Init(__CKSRC__,__BUFFERED__,__PERIOD__)\
      MWT(\
        __DRV_PTM0_Disable();\
        CH = 0; CHRL = HIBYTE(65536-(__PERIOD__));\
        CL = 0; CLRL = LOBYTE(65536-(__PERIOD__));\
        __DRV_PTM0_ClockSource_Select(__CKSRC__);\
        CMOD = CMOD & 0x8F;\
        CMOD = CMOD | (__BUFFERED__&0x70);\
        )

/**
 *******************************************************************************
 * @brief       Starts the PTM0 channel 0 PWM output.
 * @details
 * @param[in]   __RES__ : PWMn Resolution Setting
 * @arg\b       PTM0_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b       PTM0_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b       PTM0_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b       PTM0_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]   __DUTY__ : specifies PTM0 Channel 0 duty cycle(0~65535)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM0_Start(PTM0_PWM_16BIT,0x8000);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM0_Start(__RES__,__DUTY__)\
      MWT(\
        __RES__==PTM0_PWM_8BIT?(CCAP0H = LOBYTE(__DUTY__)):(CCAP0H = HIBYTE(__DUTY__));\
        PCAPWM0 = (PCAPWM0 & ~(P0RS1 | P0RS0)) | __RES__;\
        CCAPM0 = (ECOM0 | PWM0);\
        CCAP0L = LOBYTE(__DUTY__);\
        __DRV_PTM0_Enable();\
        )

/**
 *******************************************************************************
 * @brief       Starts the PTM0 channel 1 PWM output.
 * @details
 * @param[in]   __RES__ : PWMn Resolution Setting
 * @arg\b       PTM0_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b       PTM0_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b       PTM0_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b       PTM0_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]   __DUTY__ : specifies PTM0 Channel 1 duty cycle(0~65535)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM1_Start(PTM0_PWM_16BIT,0x8000);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM1_Start(__RES__,__DUTY__)\
      MWT(\
        __RES__==PTM0_PWM_8BIT?(CCAP1H = LOBYTE(__DUTY__)):(CCAP1H = HIBYTE(__DUTY__));\
        CCAP1L = LOBYTE(__DUTY__);\
        PCAPWM1 = (PCAPWM1 & ~(P1RS1 | P1RS0)) | __RES__;\
        CCAPM1 = (ECOM1 | PWM1);\
        __DRV_PTM0_Enable();\
        )

/**
 *******************************************************************************
 * @brief       Starts the PTM0 channel 2 PWM output.
 * @details
 * @param[in]   __RES__ : PWMn Resolution Setting
 * @arg\b       PTM0_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b       PTM0_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b       PTM0_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b       PTM0_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]   __DUTY__ : specifies PTM0 Channel 2 duty cycle(0~65535)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM2_Start(PTM0_PWM_16BIT,0x8000);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM2_Start(__RES__,__DUTY__)\
      MWT(\
        __RES__==PTM0_PWM_8BIT?(CCAP2H = LOBYTE(__DUTY__)):(CCAP2H = HIBYTE(__DUTY__));\
        CCAP2L = LOBYTE(__DUTY__);\
        PCAPWM2 = (PCAPWM2 & ~(P2RS1 | P2RS0)) | __RES__;\
        CCAPM2 = (ECOM2 | PWM2);\
        __DRV_PTM0_Enable();\
        )

/**
 *******************************************************************************
 * @brief       Starts the PTM0 channel 3 PWM output.
 * @details
 * @param[in]   __RES__ : PWMn Resolution Setting
 * @arg\b       PTM0_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b       PTM0_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b       PTM0_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b       PTM0_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]   __DUTY__ : specifies PTM0 Channel 3 duty cycle(0~65535)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM3_Start(PTM0_PWM_16BIT,0x8000);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM3_Start(__RES__,__DUTY__)\
      MWT(\
        __RES__==PTM0_PWM_8BIT?(CCAP3H = LOBYTE(__DUTY__)):(CCAP3H = HIBYTE(__DUTY__));\
        CCAP3L = LOBYTE(__DUTY__);\
        PCAPWM3 = (PCAPWM3 & ~(P3RS1 | P3RS0)) | __RES__;\
        CCAPM3 = (ECOM3 | PWM3);\
        __DRV_PTM0_Enable();\
        )

/**
 *******************************************************************************
 * @brief       Starts the PTM0 channel 4 PWM output.
 * @details
 * @param[in]   __RES__ : PWMn Resolution Setting
 * @arg\b       PTM0_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b       PTM0_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b       PTM0_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b       PTM0_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]   __DUTY__ : specifies PTM0 Channel 4 duty cycle(0~65535)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM4_Start(PTM0_PWM_16BIT,0x8000);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM4_Start(__RES__,__DUTY__)\
      MWT(\
        __RES__==PTM0_PWM_8BIT?(CCAP4H = LOBYTE(__DUTY__)):(CCAP4H = HIBYTE(__DUTY__));\
        CCAP4L = LOBYTE(__DUTY__);\
        PCAPWM4 = (PCAPWM4 & ~(P4RS1 | P4RS0)) | __RES__;\
        CCAPM4 = (ECOM4 | PWM4);\
        __DRV_PTM0_Enable();\
        )

/**
 *******************************************************************************
 * @brief       Starts the PTM0 channel 5 PWM output.
 * @details
 * @param[in]   __RES__ : PWMn Resolution Setting
 * @arg\b       PTM0_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b       PTM0_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b       PTM0_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b       PTM0_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]   __DUTY__ : specifies PTM0 Channel 5 duty cycle(0~65535)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM5_Start(PTM0_PWM_16BIT,0x8000);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM5_Start(__RES__,__DUTY__)\
      MWT(\
        __RES__==PTM0_PWM_8BIT?(CCAP5H = LOBYTE(__DUTY__)):(CCAP5H = HIBYTE(__DUTY__));\
        CCAP5L = LOBYTE(__DUTY__);\
        PCAPWM5 = (PCAPWM5 & ~(P5RS1 | P5RS0)) | __RES__;\
        CCAPM5 = (ECOM5 | PWM5);\
        __DRV_PTM0_Enable();\
        )

/**
 *******************************************************************************
 * @brief       Stop the PTM0 PWM channel 0.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM0_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM0_Stop()\
        (CCAPM0 = CCAPM0 & 0x01)

/**
 *******************************************************************************
 * @brief       Stop the PTM0 PWM channel 1.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM1_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM1_Stop()\
        (CCAPM1 = CCAPM1 & 0x01)

/**
 *******************************************************************************
 * @brief       Stop the PTM0 PWM channel 2.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM2_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM2_Stop()\
        (CCAPM2 = CCAPM2 & 0x01)

/**
 *******************************************************************************
 * @brief       Stop the PTM0 PWM channel 3.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM3_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM3_Stop()\
        (CCAPM3 = CCAPM3 & 0x01)

/**
 *******************************************************************************
 * @brief       Stop the PTM0 PWM channel 4.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM4_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM4_Stop()\
        (CCAPM4 = CCAPM4 & 0x01)

/**
 *******************************************************************************
 * @brief       Stop the PTM0 PWM channel 5.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM5_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM5_Stop()\
        (CCAPM5 = CCAPM5 & 0x01)


/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 PWM0 output
 * @details
 * @param[in] __STATE__ :  Configure PWM0 output
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_PWM0_Output_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM0_Output_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(PAOE = PAOE | POE0):(PAOE = PAOE & ~(POE0))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 PWM1 output
 * @details
 * @param[in] __STATE__ :  Configure PWM1 output
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_PWM1_Output_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM1_Output_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(PAOE = PAOE | POE1):(PAOE = PAOE & ~(POE1))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 PWM2 output
 * @details
 * @param[in] __STATE__ :  Configure PWM2 output
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_PWM2_Output_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM2_Output_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(PAOE = PAOE | POE2):(PAOE = PAOE & ~(POE2))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 PWM3 output
 * @details
 * @param[in] __STATE__ :  Configure PWM3 output
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_PWM3_Output_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM3_Output_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(PAOE = PAOE | POE3):(PAOE = PAOE & ~(POE3))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 PWM4 output
 * @details
 * @param[in] __STATE__ :  Configure PWM4 output
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_PWM4_Output_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM4_Output_Cmd(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(C0AOE1_Page);\
        __STATE__==MW_ENABLE?(C0AOE1 = C0AOE1 | POE4):(C0AOE1 = C0AOE1 & ~(POE4));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 PWM5 output
 * @details
 * @param[in] __STATE__ :  Configure PWM5 output
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_PWM5_Output_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM5_Output_Cmd(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(C0AOE1_Page);\
        __STATE__==MW_ENABLE?(C0AOE1 = C0AOE1 | POE5):(C0AOE1 = C0AOE1 & ~(POE5));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 PWM0A output
 * @details
 * @param[in] __STATE__ :  Configure PWM0A output
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_PWM0A_Output_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM0A_Output_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(PAOE = PAOE | POE0A):(PAOE = PAOE & ~(POE0A))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 PWM0B output
 * @details
 * @param[in] __STATE__ :  Configure PWM0B output
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_PWM0B_Output_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM0B_Output_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(PAOE = PAOE | POE0B):(PAOE = PAOE & ~(POE0B))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 PWM2A output
 * @details
 * @param[in] __STATE__ :  Configure PWM2A output
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_PWM2A_Output_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM2A_Output_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(PAOE = PAOE | POE2A):(PAOE = PAOE & ~(POE2A))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 PWM2B output
 * @details
 * @param[in] __STATE__ :  Configure PWM2B output
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_PWM2B_Output_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM2B_Output_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(PAOE = PAOE | POE2B):(PAOE = PAOE & ~(POE2B))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 PWM central aligned
 * @details
 * @param[in] __STATE__ :  Configure PWM edge aligned or central aligned
 *  @arg\b    MW_ENABLE : PTM0 PWM central aligned mode
 *  @arg\b    MW_DISABLE : PTM0 PWM edge aligned mode  (Default)
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_PWM_CentralAligned_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM_CentralAligned_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(PWMCR = PWMCR | PCAE):(PWMCR = PWMCR & ~(PCAE))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 interrupts
 * @details
 * @param[in] __STATE__ :  Configure PTM0 interrupts
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_IT_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_IT_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(EIE1 = EIE1 | EPTM0):(EIE1 = EIE1 & ~(EPTM0))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 counter overflow interrupt
 * @details
 * @param[in] __STATE__ :  Configure PTM0 counter overflow interrupt
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_Counter_IT_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Counter_IT_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(CMOD = CMOD | ECF):(CMOD = CMOD & ~(ECF))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 module 0 interrupt
 * @details
 * @param[in] __STATE__ :  Configure PTM0 Module 0 interrupts
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_Module0_IT_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Module0_IT_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(CCAPM0 = CCAPM0 | ECCF0):(CCAPM0 = CCAPM0 & ~(ECCF0))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 module 1 interrupt
 * @details
 * @param[in] __STATE__ :  Configure PTM0 Module 1 interrupts
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_Module1_IT_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Module1_IT_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(CCAPM1 = CCAPM1 | ECCF1):(CCAPM1 = CCAPM1 & ~(ECCF1))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 module 2 interrupt
 * @details
 * @param[in] __STATE__ :  Configure PTM0 Module 2 interrupts
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_Module2_IT_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Module2_IT_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(CCAPM2 = CCAPM2 | ECCF2):(CCAPM2 = CCAPM2 & ~(ECCF2))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 module 3 interrupt
 * @details
 * @param[in] __STATE__ :  Configure PTM0 Module 3 interrupts
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_Module3_IT_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Module3_IT_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(CCAPM3 = CCAPM3 | ECCF3):(CCAPM3 = CCAPM3 & ~(ECCF3))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 module 4 interrupt
 * @details
 * @param[in] __STATE__ :  Configure PTM0 Module 4 interrupts
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_Module4_IT_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Module4_IT_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(CCAPM4 = CCAPM4 | ECCF4):(CCAPM4 = CCAPM4 & ~(ECCF4))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 module 5 interrupt
 * @details
 * @param[in] __STATE__ :  Configure PTM0 Module 5 interrupts
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_Module5_IT_Cmd(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_Module5_IT_Cmd(__STATE__)\
        __STATE__==MW_ENABLE?(CCAPM5 = CCAPM5 | ECCF5):(CCAPM5 = CCAPM5 & ~(ECCF5))

/**
 *******************************************************************************
 * @brief       Initializes the PTM0 base unit for PWM with dead time according to the specified
 * @details
 * @param[in]   __CKSRC__ : specifies PTM0 clock selection
 *  @arg\b      PTM0_CK_SYSCLK_DIV_12 : PTM0 clock source by system clock with divider 12
 *  @arg\b      PTM0_CK_SYSCLK_DIV_2 : PTM0 clock source by system clock with divider 2
 *  @arg\b      PTM0_CK_T0OF : PTM0 clock source by timer0 overflow
 *  @arg\b      PTM0_CK_ECI : PTM0 clock source by ECI pin
 *  @arg\b      PTM0_CK_CKMX16 : PTM0 clock source by CKMIX16
 *  @arg\b      PTM0_CK_SYSCLK_DIV_1 : PTM0 clock source by system clock
 *  @arg\b      PTM0_CK_S0TOF : PTM0 clock source by S0BRG overflow
 *  @arg\b      PTM0_CK_MCKDO : PTM0 clock source by MCK divider output
 * @param[in]   __PERIOD__ : specifies PTM0 period (0~65536)
 * @param[in]   __DTCKSRC__ : specifies Dead Time counter
 *  @arg\b      PTM0_DTCK_SYSTEM_DIV_1 : Clock Pre-Scaler of Dead Time counter by system clock
 *  @arg\b      PTM0_DTCK_SYSTEM_DIV_2 : Clock Pre-Scaler of Dead Time counter by system clock with divider 2
 *  @arg\b      PTM0_DTCK_SYSTEM_DIV_4 : Clock Pre-Scaler of Dead Time counter by system clock with divider 4
 *  @arg\b      PTM0_DTCK_SYSTEM_DIV_8 : Clock Pre-Scaler of Dead Time counter by system clock with divider 8
 * @param[in]   __DTPERIOD__ : specifies Dead-Time period (0~63)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM_DTG_Init(PTM0_CK_SYSCLK_DIV_2,1023,PTM0_DTCK_SYSTEM_DIV_1,2);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PTM0_Dead_Time_Control_definition
#define PTM0_DTCK_SYSTEM_DIV_1          (0x00)
#define PTM0_DTCK_SYSTEM_DIV_2          (DTPS0)
#define PTM0_DTCK_SYSTEM_DIV_4          (DTPS1)
#define PTM0_DTCK_SYSTEM_DIV_8          (DTPS1 | DTPS0)
/// @endcond

#define __DRV_PTM0_PWM_DTG_Init(__CKSRC__,__PERIOD__,__DTCKSRC__,__DTPERIOD__)\
      MWT(\
        __DRV_PTM0_Disable();\
        CH = 0; CHRL = HIBYTE(65536-(__PERIOD__));\
        CL = 0; CLRL = LOBYTE(65536-(__PERIOD__));\
        __DRV_PTM0_ClockSource_Select(__CKSRC__);\
        __DRV_SFR_PageIndex(PDTCRA_Page);\
        PDTCRA = __DTCKSRC__ | (__DTPERIOD__ & 0x3F);\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief      Starts the PWM with dead time channel 0 and channel 1 PWM output.
 * @details
 * @param[in]  __RES__ : PWMn Resolution Setting
 * @arg\b      PTM0_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b      PTM0_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b      PTM0_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b      PTM0_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]  __DUTY__ : specifies PTM0 duty cycle(0~65535)
 * @return     None
 * @note
 * @par        Example
 * @code
 *    __DRV_PTM0_PWM01_DTG_Start(PTM0_PWM_8BIT,254);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM01_DTG_Start(__RES__,__DUTY__)\
      MWT(\
        __RES__==PTM0_PWM_8BIT?(CCAP0H = CCAP1H = LOBYTE(__DUTY__)):(CCAP0H = (CCAP1H = HIBYTE(__DUTY__)));\
        CCAP0L = CCAP1L = LOBYTE(__DUTY__);\
        PCAPWM0 = (PCAPWM0 & ~(P0RS1 | P0RS0)) | __RES__;\
        PCAPWM1 = (PCAPWM1 & ~(P1RS1 | P1RS0)) | __RES__;\
        CMOD = CMOD | BME0;\
        CCAPM0 = (ECOM0 | PWM0 | DTE0);\
        CCAPM1 = (ECOM0 | PWM0 );\
        __DRV_PTM0_Enable();\
        )

/**
 *******************************************************************************
 * @brief      Starts the PWM with dead time channel 2 and channel 3 PWM output.
 * @details
 * @param[in]  __RES__ : PWMn Resolution Setting
 * @arg\b      PTM0_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b      PTM0_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b      PTM0_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b      PTM0_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]  __DUTY__ : specifies PTM0 duty cycle(0~65535)
 * @return     None
 * @note
 * @par        Example
 * @code
 *    __DRV_PTM0_PWM23_DTG_Start(PTM0_PWM_8BIT,254);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM23_DTG_Start(__RES__,__DUTY__)\
      MWT(\
        __RES__==PTM0_PWM_8BIT?(CCAP2H = CCAP3H = LOBYTE(__DUTY__)):(CCAP2H = CCAP3H = HIBYTE(__DUTY__));\
        CCAP2L = CCAP3L = LOBYTE(__DUTY__);\
        PCAPWM2 = (PCAPWM2 & ~(P2RS1 | P2RS0)) | __RES__;\
        PCAPWM3 = (PCAPWM3 & ~(P3RS1 | P3RS0)) | __RES__;\
        CMOD = CMOD | BME2;\
        CCAPM2 = (ECOM0 | PWM0 | DTE0);\
        CCAPM3 = (ECOM0 | PWM0 );\
        __DRV_PTM0_Enable();\
        )

/**
 *******************************************************************************
 * @brief      Starts the PWM with dead time channel 4 and channel 5 PWM output.
 * @details
 * @param[in]  __RES__ : PWMn Resolution Setting
 * @arg\b      PTM0_PWM_8BIT : PWMn Resolution the 8bit
 * @arg\b      PTM0_PWM_10BIT : PWMn Resolution the 10bit
 * @arg\b      PTM0_PWM_12BIT : PWMn Resolution the 12bit
 * @arg\b      PTM0_PWM_16BIT : PWMn Resolution the 16bit
 * @param[in]  __DUTY__ : specifies PTM0 duty cycle(0~65535)
 * @return     None
 * @note
 * @par        Example
 * @code
 *    __DRV_PTM0_PWM45_DTG_Start(PTM0_PWM_8BIT,254);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM45_DTG_Start(__RES__,__DUTY__)\
      MWT(\
        __RES__==PTM0_PWM_8BIT?(CCAP4H = CCAP5H = LOBYTE(__DUTY__)):(CCAP4H = CCAP5H = HIBYTE(__DUTY__));\
        CCAP4L = CCAP5L = LOBYTE(__DUTY__);\
        PCAPWM4 = (PCAPWM4 & ~(P4RS1 | P4RS0)) | __RES__;\
        PCAPWM5 = (PCAPWM5 & ~(P5RS1 | P5RS0)) | __RES__;\
        CMOD = CMOD | BME4;\
        CCAPM4 = (ECOM0 | PWM0 | DTE0);\
        CCAPM5 = (ECOM0 | PWM0 );\
        __DRV_PTM0_Enable();\
        )

/**
 *******************************************************************************
 * @brief       Stop the PTM0 PWM with dead time channel 0 and channel 1 measurement.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM01_DTG_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM01_DTG_Stop()\
      MWT(\
        CCAPM0 = CCAPM0 & 0x01;\
        CCAPM1 = CCAPM1 & 0x01;\
        )

/**
 *******************************************************************************
 * @brief       Stop the PTM0 PWM with dead time channel 2 and channel 3 measurement.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM23_DTG_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM23_DTG_Stop()\
      MWT(\
        CCAPM2 = CCAPM2 & 0x01;\
        CCAPM3 = CCAPM3 & 0x01;\
        )

/**
 *******************************************************************************
 * @brief       Stop the PTM0 PWM with dead time channel 4 and channel 5 measurement.
 * @details
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM45_DTG_Stop();
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM45_DTG_Stop()\
      MWT(\
        CCAPM4 = CCAPM4 & 0x01;\
        CCAPM5 = CCAPM5 & 0x01;\
        )

/**
 *******************************************************************************
 * @brief       Update the PTM0 channel 0 duty.
 * @details
 * @param[in]   __DUTY__ : specifies PTM0 Channel 0 duty cycle Value
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM0DutyValue(256);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM0DutyValue(__DUTY__)\
      MWT(\
        CCAP0H = HIBYTE(__DUTY__);\
        CCAP0L = LOBYTE(__DUTY__);\
        )

/**
 *******************************************************************************
 * @brief       Update the PTM0 channel 1 duty.
 * @details
 * @param[in]   __DUTY__ : specifies PTM0 Channel 1 duty cycle Value
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM1DutyValue(256);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM1DutyValue(__DUTY__)\
      MWT(\
        CCAP1H = HIBYTE(__DUTY__);\
        CCAP1L = LOBYTE(__DUTY__);\
        )

/**
 *******************************************************************************
 * @brief       Update the PTM0 channel 2 duty.
 * @details
 * @param[in]   __DUTY__ : specifies PTM0 Channel 2 duty cycle Value
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM2DutyValue(256);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM2DutyValue(__DUTY__)\
      MWT(\
        CCAP2H = HIBYTE(__DUTY__);\
        CCAP2L = LOBYTE(__DUTY__);\
        )

/**
 *******************************************************************************
 * @brief       Update the PTM0 channel 3 duty.
 * @details
 * @param[in]   __DUTY__ : specifies PTM0 Channel 3 duty cycle Value
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM3DutyValue(256);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM3DutyValue(__DUTY__)\
      MWT(\
        CCAP3H = HIBYTE(__DUTY__);\
        CCAP3L = LOBYTE(__DUTY__);\
        )

/**
 *******************************************************************************
 * @brief       Update the PTM0 channel 4 duty.
 * @details
 * @param[in]   __DUTY__ : specifies PTM0 Channel 4 duty cycle Value
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM4DutyValue(256);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM4DutyValue(__DUTY__)\
      MWT(\
        CCAP4H = HIBYTE(__DUTY__);\
        CCAP4L = LOBYTE(__DUTY__);\
        )

/**
 *******************************************************************************
 * @brief       Update the PTM0 channel 5 duty.
 * @details
 * @param[in]   __DUTY__ : specifies PTM0 Channel 5 duty cycle Value
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM5DutyValue(256);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM5DutyValue(__DUTY__)\
      MWT(\
        CCAP5H = HIBYTE(__DUTY__);\
        CCAP5L = LOBYTE(__DUTY__);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PTM0 Dead Time period
 * @details
 * @param[in]   __DTCKSRC__ : specifies Dead Time counter
 *  @arg\b      PTM0_DTCK_SYSTEM_DIV_1 : Clock Pre-Scaler of Dead Time counter by system clock
 *  @arg\b      PTM0_DTCK_SYSTEM_DIV_2 : Clock Pre-Scaler of Dead Time counter by system clock with divider 2
 *  @arg\b      PTM0_DTCK_SYSTEM_DIV_4 : Clock Pre-Scaler of Dead Time counter by system clock with divider 4
 *  @arg\b      PTM0_DTCK_SYSTEM_DIV_8 : Clock Pre-Scaler of Dead Time counter by system clock with divider 8
 * @param[in]   __DTPERIOD__ : specifies Dead-Time period (0~63)
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM_DTG_period(PTM0_DTCK_SYSTEM_DIV_1,2);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM_DTG_period(__DTCKSRC__,__DTPERIOD__)\
      MWT(\
        __DRV_SFR_PageIndex(PDTCRA_Page);\
        PDTCRA = __DTCKSRC__ | (__DTPERIOD__ & 0x3F);\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PTM0 CEX0 Pin Mux
 * @details
 * @param[in]   __STATE__ : specifies CEX0 Port pin
 *  @arg\b      CEX0_P22 : CEX0=P22 (Default)
 *  @arg\b      CEX0_P40 : CEX0=P40
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_CEX0_PinMux_Select(CEX0_P40);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PTM0_CEX0_Pin_select
#define CEX0_P22     (0x00)
#define CEX0_P40     (0x01)
/// @endcond

#define __DRV_PTM0_CEX0_PinMux_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(AUXR16_Page);\
        __STATE__==CEX0_P40?(AUXR16 = AUXR16 | C0OPS0):(AUXR16 = AUXR16 & ~(C0OPS0));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PTM0 CEX1 Pin
 * @details
 * @param[in]   __STATE__ : specifies CEX1 Port pin
 *  @arg\b      CEX1_P23 : CEX1=P23 (Default)
 *  @arg\b      CEX1_P33 : CEX1=P33
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_CEX1_PinMux_Select(CEX1_P33);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PTM0_CEX1_Pin_select
#define CEX1_P23     (0x00)
#define CEX1_P33     (0x01)
/// @endcond

#define __DRV_PTM0_CEX1_PinMux_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(AUXR16_Page);\
        __STATE__==CEX1_P33?(AUXR16 = AUXR16 | C0OPS1):(AUXR16 = AUXR16 & ~(C0OPS1));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PTM0 CEX2 Pin
 * @details
 * @param[in]   __STATE__ : specifies CEX2 Port pin
 *  @arg\b      CEX2_P24 : CEX1=P24 (Default)
 *  @arg\b      CEX2_P41 : CEX1=P41
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_CEX2_PinMux_Select(CEX2_P41);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PTM0_CEX2_Pin_select
#define CEX2_P24     (0x00)
#define CEX2_P41     (0x01)
/// @endcond

#define __DRV_PTM0_CEX2_PinMux_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(AUXR16_Page);\
        __STATE__==CEX2_P41?(AUXR16 = AUXR16 | C0OPS2):(AUXR16 = AUXR16 & ~(C0OPS2));\
        __DRV_SFR_PageIndex(0);\
        )

 /**
 *******************************************************************************
 * @brief       Configure the PTM0 CEX3 Pin
 * @details
 * @param[in]   __STATE__ : specifies CEX3 Port pin
 *  @arg\b      CEX3_P05 : CEX3=P05 (Default)
 *  @arg\b      CEX3_P34 : CEX3=P34
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_CEX3_PinMux_Select(CEX3_P34);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PTM0_CEX3_Pin_select
#define CEX3_P05     (0x00)
#define CEX3_P34     (0x01)
/// @endcond

#define __DRV_PTM0_CEX3_PinMux_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(AUXR16_Page);\
        __STATE__==CEX3_P34?(AUXR16 = AUXR16 | C0OPS3):(AUXR16 = AUXR16 & ~(C0OPS3));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PTM0 CEX4 Pin
 * @details
 * @param[in]   __STATE__ : specifies CEX4 Port pin
 *  @arg\b      CEX4_P26 : CEX1=P26 (Default)
 *  @arg\b      CEX4_P32 : CEX1=P32
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_CEX4_PinMux_Select(CEX4_P32);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PTM0_CEX4_Pin_select
#define CEX4_P26     (0x00)
#define CEX4_P32     (0x01)
/// @endcond

#define __DRV_PTM0_CEX4_PinMux_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(AUXR16_Page);\
        __STATE__==CEX4_P32?(AUXR16 = AUXR16 | C0OPS4):(AUXR16 = AUXR16 & ~(C0OPS4));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PTM0 CEX5 Pin
 * @details
 * @param[in]   __STATE__ : specifies CEX5 Port pin
 *  @arg\b      CEX5_P07 : CEX5=P07 (Default)
 *  @arg\b      CEX5_P35 : CEX5=P35
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_CEX5_PinMux_Select(CEX5_P35);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PTM0_CEX5_Pin_select
#define CEX5_P07     (0x00)
#define CEX5_P35     (0x01)
/// @endcond

#define __DRV_PTM0_CEX5_PinMux_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(AUXR16_Page);\
        __STATE__==CEX5_P35?(AUXR16 = AUXR16 | C0OPS5):(AUXR16 = AUXR16 & ~(C0OPS5));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PTM0 PWM0A and PWM0B Pin
 * @details
 * @param[in]   __STATE__ : specifies PWM0x Port pin
 *  @arg\b      PWM0A_P16_PWM0B_P17 : PWM0A=P16,PWM0B=P17 (Default)
 *  @arg\b      PWM0A_P60_PWM0B_P61 : PWM0A=P60,PWM0B=P61
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM0ABMux_Select(PWM0A_P60_PWM0B_P61);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PWM0A_PWM0B_Pin_select
#define PWM0A_P16_PWM0B_P17 (0x00)
#define PWM0A_P60_PWM0B_P61 (0x01)
/// @endcond

#define __DRV_PTM0_PWM0AB_PinMux_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(AUXR5_Page);\
        __STATE__==PWM0A_P60_PWM0B_P61?(AUXR5 = AUXR5 | C0PPS0):(AUXR5 = AUXR5 & ~(C0PPS0));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PTM0 PWM2A and PWM2B Pin
 * @details
 * @param[in]   __STATE__ : specifies PWM2x Port pin
 *  @arg\b      PWM2A_P40_PWM2B_P41 : PWM2A=P40,PWM2B=P41 (Default)
 *  @arg\b      PWM2A_P34_PWM2B_P35 : PWM2A=P34,PWM2B=P35
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM2ABMux_Select(PWM2A_P34_PWM2B_P35);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PWM2A_PWM2B_Pin_select
#define PWM2A_P40_PWM2B_P41 (0x00)
#define PWM2A_P34_PWM2B_P35 (0x01)
/// @endcond

#define __DRV_PTM0_PWM2AB_PinMux_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(AUXR5_Page);\
        __STATE__==PWM2A_P34_PWM2B_P35?(AUXR5 = AUXR5 | C0PPS1):(AUXR5 = AUXR5 & ~(C0PPS1));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PTM0 ECI Pin
 * @details
 * @param[in]   __STATE__ : specifies ECI Port pin
 *  @arg\b      ECI_P02 : ECI=P02 (Default)
 *  @arg\b      ECI_P16 : ECI=P16
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_ECI_PinMux_Select(ECI_P16);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_ECI_Pin_select
#define ECI_P02 (0x00)
#define ECI_P16 (0x01)
/// @endcond

#define __DRV_PTM0_ECI_PinMux_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(AUXR5_Page);\
        __STATE__==ECI_P16?(AUXR5 = AUXR5 | ECIPS0):(AUXR5 = AUXR5 & ~(ECIPS0));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure the PTM0 Clock Output port pin Selection.
 * @details
 * @param[in]   __STATE__ : specifies C0CKO Port pin
 *  @arg\b      C0CKO_P47 : C0CKO=P47 (Default)
 *  @arg\b      C0CKO_P33 : C0CKO=P33
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_C0CKO_PinMux_Select(C0CKO_P33);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_C0CKO_Pin_select
#define C0CKO_P47 (0x00)
#define C0CKO_P33 (0x01)
/// @endcond

#define __DRV_PTM0_C0CKO_PinMux_Select(__STATE__)\
      MWT(\
        __DRV_SFR_PageIndex(AUXR5_Page);\
        __STATE__==C0CKO_P33?(AUXR5 = AUXR5 | C0COPS):(AUXR5 = AUXR5 & ~(C0COPS));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure PTM0 PWM Break Mode
 * @details
 * @param[in]   __STATE__ : PWM break mode is latched or cycle-by-cycle.
 *  @arg\b      LATCH : Latched Mode. (Default)
 *  @arg\b      CYCLE : Cycle-by-cycle Mode
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM_BreakMode_Select(CYCLE);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PWM_break_mode
#define LATCH (0x00)
#define CYCLE (0x01)
/// @endcond

#define __DRV_PTM0_PWM_BreakMode_Select(__STATE__)\
        __STATE__==CYCLE?(PWMCR = PWMCR | PBKM):(PWMCR = PWMCR & ~(PBKM))

/**
 *******************************************************************************
 * @brief       Configure PTM0 overflow flag selection.
 * @details
 * @param[in]   __STATE__ : PWM center aligned flag position.
 *  @arg\b      PTM0_PWM_TOP : CF is set on the top of central aligned PWM cycle. (Default)
 *  @arg\b      PTM0_PWM_BOTTOM : CF is set on the bottom of central aligned PWM cycle.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM_CentralAlignedFlag_Select(PTM0_PWM_BOTTOM);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PWM_overflow_flag
#define PTM0_PWM_TOP (0x00)
#define PTM0_PWM_BOTTOM (0x01)
/// @endcond

#define __DRV_PTM0_PWM_CentralAlignedFlag_Select(__STATE__)\
        __STATE__==PTM0_PWM_BOTTOM?(PWMCR = PWMCR | C0OFS):(PWMCR = PWMCR & ~(C0OFS))

/**
 *******************************************************************************
 * @brief     Enable/Disable PTM0 clock output
 * @details   Enable PCA0 clock output with PCA0 base timer overflow rate/2.
 * @param[in] __STATE__ : Configure PTM0 clock output
 *            This parameter can be: MW_ENABLE or MW_DISABLE.
 * @return    None
 * @note
 * @par       Example
 * @code
 *    __DRV_PTM0_SetClockOutput(MW_ENABLE);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetClockOutput(__STATE__)\
    MWT(\
        __DRV_SFR_PageIndex(AUXR7_Page);\
        __STATE__==MW_ENABLE?(AUXR7 = AUXR7 | C0CKOE):(AUXR7 = AUXR7 & ~(C0CKOE));\
        __DRV_SFR_PageIndex(0);\
        )

/**
 *******************************************************************************
 * @brief       Configure PTM0 PWM Break Source 0
 * @details
 * @param[in]   __STATE__ : PWM break Source0 select.
 *  @arg\b      BREAK0_DISABLE : Disable break Source0 (Default)
 *  @arg\b      BREAK0_AC0OUT : AC0 Output
 *  @arg\b      BREAK0_INT1ET : nINT1 active
 *  @arg\b      BREAK0_T2EXI : T2EXI(from Timer2)
 *  @arg\b      BREAK0_KBIET :  KBI match active
 *  @arg\b      BREAK0_AC1OUT : AC1 Output
 *  @arg\b      BREAK0_INT3ET : nINT3 active
 *  @arg\b      BREAK0_ADCWI : ADC window detect flag
 * @return      None
 * @note        This function is only active on CEXn output mode (n=0~5).
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM_BreakSource0_Select(BREAK0_AC0OUT);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_Break_Source0_select
#define BREAK0_DISABLE (0x00)
#define BREAK0_AC0OUT  (PBKE00)
#define BREAK0_INT1ET  (PBKE01)
#define BREAK0_T2EXI   (PBKE01|PBKE00)
#define BREAK0_KBIET   (PBKE02)
#define BREAK0_AC1OUT  (PBKE02|PBKE00)
#define BREAK0_INT3ET  (PBKE02|PBKE01)
#define BREAK0_ADCWI   (PBKE02|PBKE01|PBKE00)
/// @endcond

#define __DRV_PTM0_PWM_BreakSource0_Select(__STATE__)\
        PWMCR = (PWMCR & ~(PBKE02|PBKE01|PBKE00)) | __STATE__;\

/**
 *******************************************************************************
 * @brief       Configure PTM0 PWM Break Source 1
 * @details
 * @param[in]   __STATE__ : PWM break Source1 select.
 *  @arg\b      BREAK1_DISABLE : Disable break Source1 (Default)
 *  @arg\b      BREAK1_INT2ET : nINT2 active
 *  @arg\b      BREAK1_T3EXI : T3EXI(from Timer3)
 *  @arg\b      BREAK1_KBIET : KBI match active
 * @return      None
 * @note        This function is only active on CEXn output mode (n=0~5).
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM_BreakSource1_Select(Break1_INT2ET);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_Break_Source1_select
#define BREAK1_DISABLE (0x00)
#define BREAK1_INT2ET  (PBKE10)
#define BREAK1_T3EXI   (PBKE11)
#define BREAK1_OP0ES   (PBKE11|PBKE10)
/// @endcond

#define __DRV_PTM0_PWM_BreakSource1_Select(__STATE__)\
        PWMCR = (PWMCR & ~(PBKE11|PBKE10)) | __STATE__;\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM 0 extened 9th bit(MSB bit), associated with CCAP0L to become a 9-bit resgister used in PWM mode.(CCAP0L)
 * @param[in]   __VALUE__: PWM 9th bit value is 0 or 1
 *  @arg\b      Value : 0~1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM0DutyValue9thLow(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM0DutyValue9thLow(__VALUE__)\
        __VALUE__==0?(PCAPWM0 = PCAPWM0 & ~(ECAP0L)):(PCAPWM0 = PCAPWM0 | ECAP0L);\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM 1 extened 9th bit(MSB bit), associated with CCAP1L to become a 9-bit resgister used in PWM mode.(CCAP1L)
 * @param[in]   __VALUE__: PWM 9th bit value is 0 or 1
 *  @arg\b      Value : 0~1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM1DutyValue9thLow(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM1DutyValue9thLow(__VALUE__)\
        __VALUE__==0?(PCAPWM1 = PCAPWM1 & ~(ECAP1L)):(PCAPWM1 = PCAPWM1 | ECAP1L);\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM 2 extened 9th bit(MSB bit), associated with CCAP2L to become a 9-bit resgister used in PWM mode.(CCAP2L)
 * @param[in]   __VALUE__: PWM 9th bit value is 0 or 1
 *  @arg\b      Value : 0~1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM2DutyValue9thLow(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM2DutyValue9thLow(__VALUE__)\
        __VALUE__==0?(PCAPWM2 = PCAPWM2 & ~(ECAP2L)):(PCAPWM2 = PCAPWM2 | ECAP2L);\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM 3 extened 9th bit(MSB bit), associated with CCAP3L to become a 9-bit resgister used in PWM mode.(CCAP3L)
 * @param[in]   __VALUE__: PWM 9th bit value is 0 or 1
 *  @arg\b      Value : 0~1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM3DutyValue9thLow(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM3DutyValue9thLow(__VALUE__)\
        __VALUE__==0?(PCAPWM3 = PCAPWM3 & ~(ECAP3L)):(PCAPWM3 = PCAPWM3 | ECAP3L);\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM 4 extened 9th bit(MSB bit), associated with CCAP4L to become a 9-bit resgister used in PWM mode.(CCAP4L)
 * @param[in]   __VALUE__: PWM 9th bit value is 0 or 1
 *  @arg\b      Value : 0~1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM4DutyValue9thLow(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM4DutyValue9thLow(__VALUE__)\
        __VALUE__==0?(PCAPWM4 = PCAPWM4 & ~(ECAP4L)):(PCAPWM4 = PCAPWM4 | ECAP4L);\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM 5 extened 9th bit(MSB bit), associated with CCAP5L to become a 9-bit resgister used in PWM mode.(CCAP5L)
 * @param[in]   __VALUE__: PWM 9th bit value is 0 or 1
 *  @arg\b      Value : 0~1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM5DutyValue9thLow(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM5DutyValue9thLow(__VALUE__)\
        __VALUE__==0?(PCAPWM5 = PCAPWM5 & ~(ECAP5L)):(PCAPWM5 = PCAPWM5 | ECAP5L);\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM 0 extened 9th bit(MSB bit), associated with CCAP0H to become a 9-bit resgister used in PWM mode.(CCAP0H)
 * @param[in]   __VALUE__: PWM 9th bit value is 0 or 1
 *  @arg\b      Value : 0~1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM0DutyValue9thHigh(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM0DutyValue9thHigh(__VALUE__)\
        __VALUE__==0?(PCAPWM0 = PCAPWM0 & ~(ECAP0H)):(PCAPWM0 = PCAPWM0 | ECAP0H);\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM 1 extened 9th bit(MSB bit), associated with CCAP1H to become a 9-bit resgister used in PWM mode.(CCAP1H)
 * @param[in]   __VALUE__: PWM 9th bit value is 0 or 1
 *  @arg\b      Value : 0~1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM1DutyValue9thHigh(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM1DutyValue9thHigh(__VALUE__)\
        __VALUE__==0?(PCAPWM1 = PCAPWM1 & ~(ECAP1H)):(PCAPWM1 = PCAPWM1 | ECAP1H);\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM 2 extened 9th bit(MSB bit), associated with CCAP2H to become a 9-bit resgister used in PWM mode.(CCAP2H)
 * @param[in]   __VALUE__: PWM 9th bit value is 0 or 1
 *  @arg\b      Value : 0~1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM2DutyValue9thHigh(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM2DutyValue9thHigh(__VALUE__)\
        __VALUE__==0?(PCAPWM2 = PCAPWM2 & ~(ECAP2H)):(PCAPWM2 = PCAPWM2 | ECAP2H);\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM 3 extened 9th bit(MSB bit), associated with CCAP3H to become a 9-bit resgister used in PWM mode.(CCAP3H)
 * @param[in]   __VALUE__: PWM 9th bit value is 0 or 1
 *  @arg\b      Value : 0~1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM3DutyValue9thHigh(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM3DutyValue9thHigh(__VALUE__)\
        __VALUE__==0?(PCAPWM3 = PCAPWM3 & ~(ECAP3H)):(PCAPWM3 = PCAPWM3 | ECAP3H);\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM 4 extened 9th bit(MSB bit), associated with CCAP4H to become a 9-bit resgister used in PWM mode.(CCAP4H)
 * @param[in]   __VALUE__: PWM 9th bit value is 0 or 1
 *  @arg\b      Value : 0~1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM4DutyValue9thHigh(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM4DutyValue9thHigh(__VALUE__)\
        __VALUE__==0?(PCAPWM4 = PCAPWM4 & ~(ECAP4H)):(PCAPWM4 = PCAPWM4 | ECAP4H);\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM 5 extened 9th bit(MSB bit), associated with CCAP5H to become a 9-bit resgister used in PWM mode.(CCAP5H)
 * @param[in]   __VALUE__: PWM 9th bit value is 0 or 1
 *  @arg\b      Value : 0~1
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_SetPWM5DutyValue9thHigh(0);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_SetPWM5DutyValue9thHigh(__VALUE__)\
        __VALUE__==0?(PCAPWM5 = PCAPWM5 & ~(ECAP5H)):(PCAPWM5 = PCAPWM5 | ECAP5H);\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM0 resolution
 * @param[in]   __VALUE__: PWM0 resolution
 *  @arg\b      PTM0_PWM_8BIT : 8 bit PWMn, the overflow is active when [CH, CL] counts XXXX-XXXX-1111-1111 -> XXXX-XXXX-0000-0000.
 *  @arg\b      PTM0_PWM_10BIT : 10 bit PWMn, the overflow is active when [CH, CL] counts XXXX-XX11-1111-1111 -> XXXX-XX00-0000-0000.
 *  @arg\b      PTM0_PWM_12BIT : 12 bit PWMn, the overflow is active when [CH, CL] counts XXXX-1111-1111-1111 -> XXXX-0000-0000-0000.
 *  @arg\b      PTM0_PWM_16BIT : 16 bit PWMn, the overflow is active when [CH, CL] counts 1111-1111-1111-1111 -> 0000-0000-0000-0000.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM0Resolution_Select(PTM0_PWM_8BIT);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM0Resolution_Select(__VALUE__)\
        PCAPWM0 = (PCAPWM0 & ~(P0RS1 | P0RS0)) | __VALUE__;\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM1 resolution
 * @param[in]   __VALUE__: PWM1 resolution
 *  @arg\b      PTM0_PWM_8BIT : 8 bit PWMn, the overflow is active when [CH, CL] counts XXXX-XXXX-1111-1111 -> XXXX-XXXX-0000-0000.
 *  @arg\b      PTM0_PWM_10BIT : 10 bit PWMn, the overflow is active when [CH, CL] counts XXXX-XX11-1111-1111 -> XXXX-XX00-0000-0000.
 *  @arg\b      PTM0_PWM_12BIT : 12 bit PWMn, the overflow is active when [CH, CL] counts XXXX-1111-1111-1111 -> XXXX-0000-0000-0000.
 *  @arg\b      PTM0_PWM_16BIT : 16 bit PWMn, the overflow is active when [CH, CL] counts 1111-1111-1111-1111 -> 0000-0000-0000-0000.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM1Resolution_Select(PTM0_PWM_8BIT);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM1Resolution_Select(__VALUE__)\
        PCAPWM1 = (PCAPWM1 & ~(P1RS1 | P1RS0)) | __VALUE__;\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM2 resolution
 * @param[in]   __VALUE__: PWM2 resolution
 *  @arg\b      PTM0_PWM_8BIT : 8 bit PWMn, the overflow is active when [CH, CL] counts XXXX-XXXX-1111-1111 -> XXXX-XXXX-0000-0000.
 *  @arg\b      PTM0_PWM_10BIT : 10 bit PWMn, the overflow is active when [CH, CL] counts XXXX-XX11-1111-1111 -> XXXX-XX00-0000-0000.
 *  @arg\b      PTM0_PWM_12BIT : 12 bit PWMn, the overflow is active when [CH, CL] counts XXXX-1111-1111-1111 -> XXXX-0000-0000-0000.
 *  @arg\b      PTM0_PWM_16BIT : 16 bit PWMn, the overflow is active when [CH, CL] counts 1111-1111-1111-1111 -> 0000-0000-0000-0000.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM2Resolution_Select(PTM0_PWM_8BIT);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM2Resolution_Select(__VALUE__)\
        PCAPWM2 = (PCAPWM2 & ~(P2RS1 | P2RS0)) | __VALUE__;\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM3 resolution
 * @param[in]   __VALUE__: PWM3 resolution
 *  @arg\b      PTM0_PWM_8BIT : 8 bit PWMn, the overflow is active when [CH, CL] counts XXXX-XXXX-1111-1111 -> XXXX-XXXX-0000-0000.
 *  @arg\b      PTM0_PWM_10BIT : 10 bit PWMn, the overflow is active when [CH, CL] counts XXXX-XX11-1111-1111 -> XXXX-XX00-0000-0000.
 *  @arg\b      PTM0_PWM_12BIT : 12 bit PWMn, the overflow is active when [CH, CL] counts XXXX-1111-1111-1111 -> XXXX-0000-0000-0000.
 *  @arg\b      PTM0_PWM_16BIT : 16 bit PWMn, the overflow is active when [CH, CL] counts 1111-1111-1111-1111 -> 0000-0000-0000-0000.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM3Resolution_Select(PTM0_PWM_8BIT);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM3Resolution_Select(__VALUE__)\
        PCAPWM3 = (PCAPWM3 & ~(P3RS1 | P3RS0)) | __VALUE__;\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM4 resolution
 * @param[in]   __VALUE__: PWM4 resolution
 *  @arg\b      PTM0_PWM_8BIT : 8 bit PWMn, the overflow is active when [CH, CL] counts XXXX-XXXX-1111-1111 -> XXXX-XXXX-0000-0000.
 *  @arg\b      PTM0_PWM_10BIT : 10 bit PWMn, the overflow is active when [CH, CL] counts XXXX-XX11-1111-1111 -> XXXX-XX00-0000-0000.
 *  @arg\b      PTM0_PWM_12BIT : 12 bit PWMn, the overflow is active when [CH, CL] counts XXXX-1111-1111-1111 -> XXXX-0000-0000-0000.
 *  @arg\b      PTM0_PWM_16BIT : 16 bit PWMn, the overflow is active when [CH, CL] counts 1111-1111-1111-1111 -> 0000-0000-0000-0000.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM4Resolution_Select(PTM0_PWM_8BIT);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM4Resolution_Select(__VALUE__)\
        PCAPWM4 = (PCAPWM4 & ~(P4RS1 | P4RS0)) | __VALUE__;\

/**
 *******************************************************************************
 * @brief       Set PTM0 PWM5 resolution
 * @param[in]   __VALUE__: PWM5 resolution
 *  @arg\b      PTM0_PWM_8BIT : 8 bit PWMn, the overflow is active when [CH, CL] counts XXXX-XXXX-1111-1111 -> XXXX-XXXX-0000-0000.
 *  @arg\b      PTM0_PWM_10BIT : 10 bit PWMn, the overflow is active when [CH, CL] counts XXXX-XX11-1111-1111 -> XXXX-XX00-0000-0000.
 *  @arg\b      PTM0_PWM_12BIT : 12 bit PWMn, the overflow is active when [CH, CL] counts XXXX-1111-1111-1111 -> XXXX-0000-0000-0000.
 *  @arg\b      PTM0_PWM_16BIT : 16 bit PWMn, the overflow is active when [CH, CL] counts 1111-1111-1111-1111 -> 0000-0000-0000-0000.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_PWM5Resolution_Select(PTM0_PWM_8BIT);
 * @endcode
 *******************************************************************************
 */
#define __DRV_PTM0_PWM5Resolution_Select(__VALUE__)\
        PCAPWM5 = (PCAPWM5 & ~(P5RS1 | P5RS0)) | __VALUE__;\

/**
 *******************************************************************************
 * @brief       Configure PTM0 POEn control Mode
 * @details
 * @param[in]   __STATE__ : POEn control is CPU writing or PWM cycle.
 *  @arg\b      CPU_WRITING : POEn function is active immediately after CPU writing. (Default)
 *  @arg\b      PWM_CYCLE : POEn function is aligned to PWM cycle.
 * @return      None
 * @note
 * @par         Example
 * @code
 *    __DRV_PTM0_POEnControl_Select(PWM_CYCLE);
 * @endcode
 *******************************************************************************
 */
/// @cond defgroup_PWM_break_mode
#define CPU_WRITING (0x00)
#define PWM_CYCLE   (0x01)
/// @endcond

#define __DRV_PTM0_POEnControl_Select(__STATE__)\
      MWT(\
          __DRV_SFR_PageIndex(C0AOE1_Page);\
          __STATE__==PWM_CYCLE?(C0AOE1 = C0AOE1 | POEM0):(C0AOE1 = C0AOE1 & ~(POEM0));\
          __DRV_SFR_PageIndex(0);\
         )

/**
*******************************************************************************
* @brief       Get PTM0 Module0 flag.
* @details     Set by hardware when a match occurs.
* @return      Data type bit
* @note        None
* @par         Example
* @code
     __DRV_PTM0_Module0_GetFlag(user_define);
* @endcode
*******************************************************************************
*/
#define __DRV_PTM0_Module0_GetFlag(__VALUE__)\
    MWT(\
        __VALUE__= CCF0;\
     )

/**
*******************************************************************************
* @brief       Get PTM0 Module1 flag.
* @details     Set by hardware when a match occurs.
* @return      Data type bit
* @note        None
* @par         Example
* @code
     __DRV_PTM0_Module1_GetFlag(user_define);
* @endcode
*******************************************************************************
*/
#define __DRV_PTM0_Module1_GetFlag(__VALUE__)\
    MWT(\
        __VALUE__= CCF1;\
     )

/**
*******************************************************************************
* @brief       Get PTM0 Module2 flag.
* @details     Set by hardware when a match occurs.
* @return      Data type bit
* @note        None
* @par         Example
* @code
     __DRV_PTM0_Module2_GetFlag(user_define);
* @endcode
*******************************************************************************
*/
#define __DRV_PTM0_Module2_GetFlag(__VALUE__)\
    MWT(\
        __VALUE__= CCF2;\
     )

/**
*******************************************************************************
* @brief       Get PTM0 Module3 flag.
* @details     Set by hardware when a match occurs.
* @return      Data type bit
* @note        None
* @par         Example
* @code
     __DRV_PTM0_Module3_GetFlag(user_define);
* @endcode
*******************************************************************************
*/
#define __DRV_PTM0_Module3_GetFlag(__VALUE__)\
    MWT(\
        __VALUE__= CCF3;\
     )
/**
*******************************************************************************
* @brief       Get PTM0 Module4 flag.
* @details     Set by hardware when a match occurs.
* @return      Data type bit
* @note        None
* @par         Example
* @code
     __DRV_PTM0_Module4_GetFlag(user_define);
* @endcode
*******************************************************************************
*/
#define __DRV_PTM0_Module4_GetFlag(__VALUE__)\
    MWT(\
        __VALUE__= CCF4;\
     )

/**
*******************************************************************************
* @brief       Get PTM0 Module5 flag.
* @details     Set by hardware when a match occurs.
* @return      Data type bit
* @note        None
* @par         Example
* @code
     __DRV_PTM0_Module5_GetFlag(user_define);
* @endcode
*******************************************************************************
*/
#define __DRV_PTM0_Module5_GetFlag(__VALUE__)\
    MWT(\
        __VALUE__= CCF5;\
     )

bool DRV_PTM0_GetModule0Flag(void);
bool DRV_PTM0_GetModule1Flag(void);
bool DRV_PTM0_GetModule2Flag(void);
bool DRV_PTM0_GetModule3Flag(void);
bool DRV_PTM0_GetModule4Flag(void);
bool DRV_PTM0_GetModule5Flag(void);
bool DRV_PTM0_GetOverflowFlag(void);
bool DRV_PTM0_GetBreakFlag(void);
uint16_t DRV_PTM0_GetPWM0DutyValue(void);
uint16_t DRV_PTM0_GetPWM1DutyValue(void);
uint16_t DRV_PTM0_GetPWM2DutyValue(void);
uint16_t DRV_PTM0_GetPWM3DutyValue(void);
uint16_t DRV_PTM0_GetPWM4DutyValue(void);
uint16_t DRV_PTM0_GetPWM5DutyValue(void);
#endif
